@@ -188,14 +188,12 @@ void
 construct_execution_phase_script(GB * G, CISF_PRODUCT * cisf, SWI * swi, STROB * buf, STROB * config_msg) 
 {
 	int current_return_code;
-	int is_configured;
 	int i;
 	int do_reconfigure;
 	CISF_BASE * product_base;
 	CISF_BASE * cisf_base;
 	char * current_result;
 	char * parent_tag;
-	int ret;
 	char * scriptname;
 
 	E_DEBUG("");
@@ -271,7 +269,7 @@ construct_execution_phase_script(GB * G, CISF_PRODUCT * cisf, SWI * swi, STROB *
 
 static
 int
-do_run_configure(GB * G, SWI * swi,
+do_run_configure(GB * G, SWI * swi, char * target_path,
 		SWHEADER * isf_header, CISF_PRODUCT * cisf,
 		SWICOL * swicol, SWICAT_E * e, int ofd, STROB * config_msg)
 {
@@ -287,7 +285,7 @@ do_run_configure(GB * G, SWI * swi,
 		swicol,
 		ofd,
 		512,
-		".",
+		target_path, /* WAS "."*/
 		strob_str(buf),
 		SWBIS_TS_run_configure);
 
@@ -422,9 +420,7 @@ merge_cisf_process_product(CISF_PRODUCT * cisf_product, SWHEADER * swheader)
 {
 	char * next_line;
 	char * tag;
-	char * number;
 	char * object_keyword;
-	char * keyword;
 	char * mod_time;
 	char * state;
 	char * create_time;
@@ -644,7 +640,6 @@ swconfig_write_source_copy_script2(GB * G,
 	)
 {
 	int ret;
-	char * isc_relpath;
 	char * dirname;
 	char * basename;
 	char * pax_write_command;
@@ -808,12 +803,14 @@ swconfig_write_source_copy_script2(GB * G,
 	strob_sprintf(buffer_new, STROB_DO_APPEND,
 		"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 		"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+		"echo " SWBIS_TARGET_CTL_MSG_129 ": \"`pwd | head -1`\"\n"
 		CSHID
 		"%s\n"
 		"export LOCKENTRY\n"
 		"LOCKPATH=\"\"\n"
 		"%s\n"  			/* SEVENT: SW_SESSION_BEGINS */
 		"%s" 				/* swicol_subshell_marks */
+		"wcwd=\"`pwd`\"\n"
 		"export lock_did_lock\n"
 		"export opt_force_lock\n"
 		"export swbis_ignore_scripts\n"
@@ -837,6 +834,7 @@ swconfig_write_source_copy_script2(GB * G,
 		"%s\n"			/* lf_ lock routine */
 		"%s\n"			/* shls__cleansh routine */
 		"%s\n"			/* shls_cleansh routine */
+		"%s\n"			/* shls_make_dir_absolute */
 		"%s" 			/* set statement for verbosity */
 		"export opt_to_stdout\n"
 		"opt_to_stdout=\"\"\n"
@@ -854,6 +852,44 @@ swconfig_write_source_copy_script2(GB * G,
 		"debug_task_shell=\"%s\"\n"
 		"swexec_status=0\n"
 		"export LOCKPATH\n"
+
+
+		"#\n"
+		"# make targetpath absolute\n"
+		"#\n"
+		"case \"$targetpath\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$targetpath\"\n"
+		"shls_make_dir_absolute\n"
+		"targetpath=\"$mda_target_path\"\n"
+		"# targetpath is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make absolute\n"
+		"#\n"
+
+		"#\n"
+		"# make dirname absolute\n"
+		"#\n"
+		"case \"$dirname\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$dirname\"\n"
+		"shls_make_dir_absolute\n"
+		"dirname=\"$mda_target_path\"\n"
+		"# dirname is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make dirname absolute\n"
+		"#\n"
+
 		"# Here is the override of the shls_looper_payload function\n"
 		"#\n"
 		"%s\n"    /* <<<--- shls_looper_payload looper_routine */
@@ -1003,6 +1039,7 @@ swconfig_write_source_copy_script2(GB * G,
 /*_% */	shlib_get_function_text_by_name("lf_remove_lock", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("shls__cleansh", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("shls_cleansh", shell_lib_buf, NULL),
+/*_% */	shlib_get_function_text_by_name("shls_make_dir_absolute", shell_lib_buf, NULL),
 /*_% */		strob_str(set_vx),
 /*_% */		blocksize,
 /*_% */		dirname,
@@ -1069,7 +1106,6 @@ int
 swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		SWICAT_SR * sr, int ofd, int ifd, int * p_rp_status, SWUTS * uts)
 {
-	int i;
 	int retval;
 	int rstatus;
 	int ret;
@@ -1081,11 +1117,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	int sig_level;
 	char * pax_read_command;
 	char * epath;
-	char * name;
 	char * script_name;
 	char * installed_software_catalog;
 	char * catalog_entry_directory;
-	struct stat st;
 	STROB * xxtmp;
 	STROB * btmp;
 	STROB * btmp2;
@@ -1521,7 +1555,7 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		/* End of Testing area */
 	} else {
 		E_DEBUG("run configure: really running it");
-		ret = do_run_configure(G, swi, isf_header, cisf_product, swicol, e, ofd, config_msg);
+		ret = do_run_configure(G, swi, target_path, isf_header, cisf_product, swicol, e, ofd, config_msg);
 		if (ret < 0) {
 			/* internal error */
 			E_DEBUG("internal error");
