@@ -566,7 +566,7 @@ get_delivery_size(SWI * swi, int * result)
 	*result = 0;
 	swheader_reset(indexheader);
         obj = swheader_get_object_by_tag(indexheader, SW_A_fileset, "*" );
-        line = swheader_get_attribute(indexheader, SW_A_size);
+        line = swheader_get_attribute(indexheader, SW_A_size, NULL);
 	value = swheaderline_get_value(line, NULL);
 
 	if (!value) {
@@ -759,22 +759,23 @@ int
 send_catalog_tarfile(SWI * swi, int ofd, 
 	char * catalog_path, char * pax_read_command,
 	int alt_catalog_root, int event_fd,
-	int sig_block_start, int sig_block_end)
+	int sig_block_start, int sig_block_end, char * id_str)
 	
 {
 	int ret = 0;
 	int dataret = 0;
 	int stdin_file_size;
 	STROB * tmp;
-	STROB * namebuf;
 
 	tmp = strob_open(10);
-	namebuf = strob_open(10);
 
 	/*
 	 * Here is the task scriptlet.
 	 */
-	strob_sprintf(tmp, 0,
+
+	swpl_write_chdir_catalog_fragment(tmp, catalog_path, id_str);
+
+	strob_sprintf(tmp, STROB_DO_APPEND,
 		"dd 2>/dev/null | %s\n"
 		"sw_retval=$?\n"	/* This line is required */
 		"dd of=/dev/null 2>/dev/null\n"
@@ -798,14 +799,13 @@ send_catalog_tarfile(SWI * swi, int ofd,
 	/*
 	 * Here is the directory that is chdir'ed into.
 	 */
-	strob_strcpy(namebuf, catalog_path);
 
 	swicol_set_task_idstring(swi->swicolM, SWBIS_TS_Load_catalog);
 	ret = swicol_rpsh_task_send_script2(
 		swi->swicolM,
 		ofd, 
 		stdin_file_size,
-		strob_str(namebuf),
+		swi->swi_pkgM->target_pathM,
 		strob_str(tmp), SWBIS_TS_Load_catalog
 		);
 
@@ -855,7 +855,6 @@ send_catalog_tarfile(SWI * swi, int ofd,
 			swicol_show_events_to_fd(swi->swicolM, STDERR_FILENO, -1);
 	}	
 	strob_close(tmp);
-	strob_close(namebuf);
 	return ret;
 }
 
@@ -907,6 +906,7 @@ construct_execution_phase_script(GB * G, CISF_PRODUCT * cisf, SWI * swi,
 		v_target = ".";
 		v_command = "tar tf - 1>/dev/null 2>&1";
 	}
+
 	strob_sprintf(buf, STROB_DO_APPEND,
 		CSHID
 		"\n"
@@ -1030,7 +1030,6 @@ send_files_with_no_storage(GB * G, SWI * swi, SWHEADER * infoheader, XFORMAT * x
 	char * att;
 	char * next_line;
 	char * keyword;
-	char * missing_name;
 	char * current_path;
 	char * l_current_path;
 	AHS * ahs;
@@ -1065,11 +1064,11 @@ send_files_with_no_storage(GB * G, SWI * swi, SWHEADER * infoheader, XFORMAT * x
 			}	
 			tartype = ahs_get_tar_typeflag(ahs);
 
-			att = swheader_get_attribute(infoheader, SW_A_type);
+			att = swheader_get_attribute(infoheader, SW_A_type, NULL);
 			SWLIB_ASSERT(att != NULL);
 			current_type = swheaderline_get_value(att, NULL);
 
-			att = swheader_get_attribute(infoheader, SW_A_path);
+			att = swheader_get_attribute(infoheader, SW_A_path, NULL);
 			SWLIB_ASSERT(att != NULL);
 			current_path = swheaderline_get_value(att, NULL);
 			
@@ -1097,7 +1096,7 @@ send_files_with_no_storage(GB * G, SWI * swi, SWHEADER * infoheader, XFORMAT * x
 				ahs_copy(xformat_ahs_object(xformat) /*to*/ , ahs /*from*/);
 
 				if (*current_type == SW_ITYPE_h || *current_type == SW_ITYPE_s) {
-					att = swheader_get_attribute(infoheader, SW_A_link_source);
+					att = swheader_get_attribute(infoheader, SW_A_link_source, NULL);
 					SWLIB_ASSERT(att != NULL);
 					current_link_source = swheaderline_get_value(att, NULL);
 					if (!current_link_source) {
@@ -1300,6 +1299,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	char * p_directory;
 	SWVERID * swverid;
 	CISF_PRODUCT * cisf;
+	SWI_FILELIST * fl;
 
 	E_DEBUG2("fp: catalog_path=[%s]", catalog_path);
 	signal_flag = 0;
@@ -1605,11 +1605,11 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			}
 
 			if (opt_preview == 0 && retval == 0) {
-				/* TS_catalog_load */
+				/* TS_Load_catalog */
 				ret = send_catalog_tarfile(swi, vofd, 
 					catalog_path, pax_read_command,
 					alt_catalog_root, event_fd,
-					sig_block_start, sig_block_end);
+					sig_block_start, sig_block_end, SWBIS_TS_Load_catalog);
 			} else {
 				ret = 0;
 			}
@@ -1870,6 +1870,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * ===================================================
 	 */
 
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (opt_preview == 0 && retval == 0) {
 		/* SWBIS_TS_Load_INSTALLED_90 */
@@ -1900,6 +1901,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * Send the task script for loading the fileset.
 	 * =============================================
 	 */
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	did_fileset = 1;	
 	strob_strcpy(newnamebuf, target_path);
@@ -1917,7 +1919,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			swi->swicolM,
 			vofd, 
 			payload_size,  /* fileset size plus padding */
-			".", /* strob_str(newnamebuf), */
+			swi->swi_pkgM->target_pathM,
 			strob_str(execution_phase_script), SWBIS_TS_Load_fileset);
 		if (ret == 0) {
 			/* wait for clear-to-send */
@@ -1955,8 +1957,9 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * Loop over Storage section files.
 	 * =====================================
 	 */
-	E_DEBUG2("retval = %d", retval);
-	E_DEBUG("HERE");
+	E_DEBUG2("retval=%d", retval);
+	E_DEBUG2("*p_signal_flag = %d", *p_signal_flag);
+	E_DEBUG("HERE at Loop over Storage section files");
 	taru_ls_verbose_level = -1;
 	while (
 		xformat_read_header(xformat) > 0 &&
@@ -2061,7 +2064,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				}
 			}
 
-			current_type = swheader_get_attribute(infoheader, "type");
+			current_type = swheader_get_attribute(infoheader, SW_A_type, NULL);
 			current_type = swheaderline_get_value(current_type, NULL);
 
 			if (!current_type) { 
@@ -2112,12 +2115,12 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			/*
 			 * Find the "md5sum" attribute.
 			 */
-			filemd5 = swpl_get_attribute(infoheader, "md5sum", (int *)NULL);
+			filemd5 = swpl_get_attribute(infoheader, SW_A_md5sum, (int *)NULL);
 
 			/*
 			 * Find the "is_volatile" attribute.
 			 */
-			is_volatile = swpl_get_attribute(infoheader, "is_volatile", (int *)NULL);	
+			is_volatile = swpl_get_attribute(infoheader, SW_A_is_volatile, (int *)NULL);	
 
 			if (swextopt_is_value_true(is_volatile)) {
 				/*
@@ -2198,7 +2201,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			 * Set the link name.
 			 */
 			if (*current_type == SW_ITYPE_h || *current_type == SW_ITYPE_s) {
-				current_link_source = swheader_get_attribute(infoheader, SW_A_link_source);
+				current_link_source = swheader_get_attribute(infoheader, SW_A_link_source, NULL);
 				current_link_source = swheaderline_get_value(current_link_source, NULL);
 				if (!current_link_source) { SWI_internal_error(); return -68; }
 
@@ -2371,6 +2374,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		E_DEBUG("HERE: Storage");
 	} /* while */
 
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (cmpret) {
 		fprintf(stderr,
@@ -2386,6 +2390,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		is set for all files that were found in the 
 		storage section */
 
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (*p_signal_flag == 0 && retval == 0) {
 		/* The routine swheaderline_set_flag1() called above
@@ -2417,6 +2422,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		files_missing_from_storage = 1;
 	}
 
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (opt_preview == 0) {
 		if (fileset_write_ret > (payload_size - (uintmax_t)(1024))) {
@@ -2434,6 +2440,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * the remote dd(1) process is exepecting.
 	 */
 
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (swi->verboseM > SWC_VERBOSE_10)
 	{
@@ -2450,6 +2457,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		strob_close(xx_tmp3);
 	}
 
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (retval == 0) {
 		padamount = (int)(payload_size - fileset_write_ret);
@@ -2469,6 +2477,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	/*
 	 * This waits on the fileset loading task.
 	 */
+	E_DEBUG2("retval=%d", retval);
 	E_DEBUG("HERE");
 	if (opt_preview == 0 && retval == 0) {
 		/*
@@ -2501,12 +2510,10 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		E_DEBUG("HERE");
 
 	} else {
-		E_DEBUG("HERE");
+		E_DEBUG2("retval=%d", retval);
+		E_DEBUG("HERE opt_preview mode");
 		if (
-			/* G->g_to_stdout == 0 && */
-			retval == 0 &&
-		    	swi->swc_idM == SWC_U_I && /* swinstall utility */
-		    	1
+			opt_preview
 		) {
 			/*
 		 	 * This satisfies the preview task shell
@@ -2790,8 +2797,10 @@ write_target_install_script(GB * G,
 	}
 
 	strob_sprintf(buffer_new, STROB_DO_APPEND,
+	"IFS=\"`printf ' \\t\\n'`\"\n"
 	"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 	"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+	"echo " SWBIS_TARGET_CTL_MSG_129 ": \"`pwd | head -1`\"\n"
 	CSHID
 	"%s\n" /* Session Begins */
 	"%s"
@@ -2817,6 +2826,7 @@ write_target_install_script(GB * G,
 	"%s\n"			/* lf_ lock routine */
 	"%s\n"			/* lf_ lock routine */
 	"%s\n"			/* lf_ lock routine */
+	"%s\n"			/* shls_make_dir_absolute */
 	"opt_preview=\"%s\"\n"
 	"opt_to_stdout=\"%s\"\n"
 	"LOCKPATH=\"%s\"\n"
@@ -2824,7 +2834,7 @@ write_target_install_script(GB * G,
 	"blocksize=\"%s\"\n"
 	"isc_path=\"%s\"\n"
 	"xtarget=\"%s\"\n"
-	"wcwd=`pwd`\n"
+	"wcwd=\"`pwd`\"\n"
 	"export sh_dash_s\n"
 	"d_sh_dash_s=\"%s\"\n"
 	"case \"$5\" in PSH=*) eval \"$5\";; *) unset PSH ;; esac\n"
@@ -2844,8 +2854,26 @@ write_target_install_script(GB * G,
 	"	exit $sw_retval\n"
 	"fi\n"
 	CSHID
+	"#\n"
+	"# Start of code to make absolute\n"
+	"#\n"
+	"case \"$xtarget\" in\n"
+	"/*)\n"
+	";;\n"
+	"*)\n"
+	"mda_pwd=\"$wcwd\"\n"
+	"mda_target_path=\"$xtarget\"\n"
+	"shls_make_dir_absolute\n"
+	"xtarget=\"$mda_target_path\"\n"
+	"# xtarget is now absolute\n"
+	";;\n"
+	"esac\n"
+	"#\n"
+	"# END of code to make absolute\n"
+	"#\n"
 	"cd \"$xtarget\" 2>/dev/null\n"
 	"sw_retval=$?\n"
+	"cd_retval=$sw_retval\n"
 	"if test \"$xtarget\" = '.'; then\n"
 	"	sw_retval=1\n"
 	"else\n"
@@ -2858,15 +2886,27 @@ write_target_install_script(GB * G,
 	"			sw_retval=1\n"
 	"		fi\n"
 	"	else\n"
-	"		cd \"$wcwd\"; sw_retval=1;\n"
+	"		# cd \"$xtarget\"\n"
+	"		sw_retval=1\n"
 	"	fi\n"
 	"fi\n"
-	"if test \"$sw_retval\" = \"0\"; then\n"
+	"case \"$sw_retval\" in\n"
+	"	0)\n"
 	"	%s\n"  /* SOC_CREATED */
-	"fi\n"
+	"	;;\n"
+	"esac\n"
 	CSHID
+
+	"case \"$cd_retval\" in\n"
+	"0)\n"
+	"sw_retval=0\n"
+	";;\n"
+	"*)\n"
 	"cd \"$xtarget\" 2>/dev/null\n"
 	"sw_retval=$?\n"
+	";;\n"
+	"esac\n"
+
 	"if test -d \"$isc_path\"; then\n"
 	"	echo 1>/dev/null\n"
 	"else\n"
@@ -2903,6 +2943,8 @@ write_target_install_script(GB * G,
 	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_get_catalog_perms ";; *) shls_false_;; esac\n"
 	"sw_retval=$?\n"
 	"swexec_status=$sw_retval\n"
+	"case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
+	"swexec_status=$sw_retval\n"
 
 	"case $sw_retval in 0) ;; *) swexec_status=1; sw_retval=1; ;; esac\n"
 	"case $swexec_status in	0) %s ;; *) shls_false_ ;; esac\n" 	/* SW_ANALYSIS_BEGINS */
@@ -2920,20 +2962,31 @@ write_target_install_script(GB * G,
 	"True)\n"
 	"	;;\n"
 	"*)\n"
+
+	CSHID
 	"	shls_bashin2 \"" SWBIS_TS_Get_iscs_listing "\"\n"
 	"       sw_retval=$?\n"
 	"       case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Get_iscs_listing ";; *) shls_false_;; esac\n"
 	"       sw_retval=$?\n"
-/*----*/
 	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
+	"       swexec_status=$sw_retval\n"
 
 	CSHID
-	"       swexec_status=$sw_retval\n"
 	"	shls_bashin2 \"" SWBIS_TS_Get_iscs_entry "\"\n"
 	"	sw_retval=$?\n"
 	"	case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Get_iscs_entry  ";; *) shls_false_;; esac\n"
 	"	sw_retval=$?\n"
+	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
 	"	swexec_status=$sw_retval\n"
+
+	"	shls_bashin2 \"" SWBIS_TS_check_OVERWRITE "\"\n"
+	"	sw_retval=$?\n"
+	"	case $sw_retval in 0) $sh_dash_s " SWBIS_TS_check_OVERWRITE";; *) shls_false_;; esac\n"
+	"	sw_retval=$?\n"
+	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
+	"	swexec_status=$sw_retval\n"
+	
+	CSHID
 	"	shls_bashin2 \"" SWBIS_TS_remove_catalog_entry "\"\n"
 	"	sw_retval=$?\n"
 	"	case $sw_retval in 0) wwf_did=1; $sh_dash_s " SWBIS_TS_remove_catalog_entry  ";; *) wwf_did=0; shls_false_;; esac\n"
@@ -2951,14 +3004,25 @@ write_target_install_script(GB * G,
 	"			;;\n"
 	"	esac\n"
 	"	swexec_status=$sw_retval\n"
+
 	"	;;\n"
 	"esac\n"
+
+	CSHID
+	"shls_bashin2 \"" SWBIS_TS_check_status "\"\n"
+	"sw_retval=$?\n"
+	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_check_status ";; *) shls_false_;; esac\n"
+	"sw_retval=$?\n"
+	"swexec_status=$sw_retval\n"
+
 	CSHID
 	"case \"$opt_preview\" in\n"
 	"True)\n"
 	"	shls_bashin2 \"" SWBIS_TS_preview_task "\"\n"
 	"	sw_retval=$?\n"
 	"	case $sw_retval in 0) $sh_dash_s " SWBIS_TS_preview_task ";; *) shls_false_;; esac\n"
+	"	# Here is where the preview option scuttles the rest of the script\n"
+	"	# by setting swexec_status=1\n"
 	"	swexec_status=1\n"
 	"	opt_to_stdout=\"True\"\n"
 	"	;;\n"
@@ -2970,6 +3034,7 @@ write_target_install_script(GB * G,
 	"*)\n"
 	"	;;\n"
 	"esac\n"
+
 	CSHID
 	"shls_bashin2 \"" SWBIS_TS_make_catalog_dir "\"\n"
 	"sw_retval=$?\n"
@@ -3093,6 +3158,7 @@ write_target_install_script(GB * G,
 /*_% */	shlib_get_function_text_by_name("lf_make_lockfile_entry", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("lf_test_lock", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("lf_remove_lock", shell_lib_buf, NULL),
+/*_% */	shlib_get_function_text_by_name("shls_make_dir_absolute", shell_lib_buf, NULL),
 /*_% */	opt_char_preview,
 /*_% */	opt_char_to_stdout,
 /*_% */	strob_str(catlockbuffer),
@@ -3150,6 +3216,28 @@ write_target_install_script(GB * G,
 	return retval;
 }
 
+static
+int
+report_file_conflicts(GB * G, SWI * swi, int opt_preview, int replacefiles, int keepfiles, int is_upgrade, char * name)
+{
+	int retval;
+	retval = 0;
+	
+	E_DEBUG2("HERE : replacefiles %d", replacefiles);
+	E_DEBUG2("HERE : keepfiles %d", keepfiles);
+	E_DEBUG2("HERE : is_upgrade %d", is_upgrade);
+	E_DEBUG2("HERE : %s", name);
+	if (replacefiles == 0 && keepfiles == 0 && is_upgrade == 0) {
+		if (opt_preview == 0)
+			retval = 1;
+		sw_l_msg(G, SWC_VERBOSE_1, "SW_FILE_ERROR: file exists: %s\n", name);
+	} else if (is_upgrade == 0) {
+		sw_l_msg(G, SWC_VERBOSE_1, "SW_FILE_WARNING: file exists: %s\n", name);
+	}
+	E_DEBUG2("HERE : returning %d", retval);
+	return retval;
+}
+
 /* ---------------------------------------------------------------- */
 /* ------------------ PUBLIC ---- PUBLIC -------------------------- */
 /* ----- Routines below are likely called from swinstall.c -------- */
@@ -3225,7 +3313,7 @@ swinstall_arfinstall(GB * G, SWI * swi, int ofd, int * g_signal_flag,
 		;
 	} else {
 		if (
-			swlib_check_clean_absolute_path(swi->swi_pkgM->target_pathM) ||
+			swlib_check_clean_path(swi->swi_pkgM->target_pathM) ||
 			0
 		) {
 			E_DEBUG2("HERE path is [%s]", swi->swi_pkgM->target_pathM);
@@ -3282,3 +3370,33 @@ swinstall_arfinstall(GB * G, SWI * swi, int ofd, int * g_signal_flag,
 	}
 	return ret;
 }
+
+int
+swinstall_analyze_overwrites(GB * G, SWI * swi, int overwrite_fd, int opt_keep_old_files, int is_upgrade)
+{
+	int retval;
+	STROB * buf;
+	int n;
+	int opt_preview;
+	char * s;
+	int replacefiles;
+
+	E_DEBUG("");
+	retval = 0;
+	if (overwrite_fd < 0) return 0;
+	buf = strob_open(32);
+	opt_preview = G->g_opt_previewM;
+	replacefiles = swextopt_is_option_true(SW_E_swbis_replacefiles, G->optaM);
+
+	E_DEBUG("");
+	uxfio_lseek(overwrite_fd, 0, SEEK_SET);
+	while ((n=swgp_read_line(overwrite_fd, (STROB*)buf, DO_NOT_APPEND)) > 0) {
+		s = strob_str(buf);
+		while(swlib_squash_trailing_char(s, '\n') == 0);
+		E_DEBUG("");
+		retval += report_file_conflicts(G, swi, opt_preview, replacefiles, opt_keep_old_files, is_upgrade, s);
+	}
+	strob_close(buf);
+	E_DEBUG2("returning %d", retval);
+	return retval;
+}
