@@ -49,8 +49,8 @@
 #include "globalblob.h"
 #include "swproglib.h"
 #include "swlist_lib.h"
-#include "swverify_lib.h"
 #include "swlist.h"
+#include "swverify_lib.h"
 
 #define SWLIST_UPVERBOSE	1
 #define PROGNAME                "swlist"
@@ -68,6 +68,56 @@ static GB * G;      /* pointer to Global blob */
 static BLIST g_blist;  /* Global blob of swlist specific option settings */
 static BLIST * BL;      /* Pointer to (BLIST)(g_blist)  */
 
+static int n_msg_SIGPIPE = 0;
+
+struct blist_level blist_levels_i[] = {
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_FILE,  /* must be 0 */
+		SW_A_file
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_CONTROL_FILE, /* 1 */
+		SW_A_control_file
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_FILESET, /* 2 */
+		SW_A_fileset
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_SUBPRODUCT, /* 3 */
+		SW_A_subproduct
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_PRODUCT, /* 4 */
+		SW_A_product
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_BUNDLE, /* 5 */
+		SW_A_bundle
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_DISTRIBUTION, /* 6 */
+		SW_A_distribution
+	},
+	{
+		0, /* is set*/  
+		SW_LEVEL_V_HOST, /* 7 */
+		SW_A_host
+	},
+	{
+		0,
+		0,
+		(char*)NULL
+	}
+};
+
 static
 void 
 version_string(FILE * fp)
@@ -83,14 +133,14 @@ version_info(FILE * fp)
 {
 	version_string(fp);
 	fprintf(fp,  "%s",
-"Copyright (C) 2007,2008 Jim Lowe\n"
+"Copyright (C) 2007,2008,2010 Jim Lowe\n"
 "Portions are copyright 1985-2000 Free Software Foundation, Inc.\n"
 "This software is distributed under the terms of the GNU General Public License\n"
 "and comes with NO WARRANTY to the extent permitted by law.\n"
 "See the file named COPYING for details.\n");
 
 }
-					
+
 static
 void
 write_attr(char * name, char * value, int index_format)
@@ -399,7 +449,10 @@ safe_sig_handler(int signum)
 			break;
 		case SIGPIPE:
 			if (G->g_do_progressmeter) alarm(0);
-			sw_e_msg(G, "Caught SIGPIPE\n");
+			if (n_msg_SIGPIPE == 0) {
+				sw_e_msg(G, "Caught SIGPIPE\n");
+				n_msg_SIGPIPE++;
+			}
 			G->g_signal_flag = signum;
 			if (G->g_swicolM) swicol_set_master_alarm(G->g_swicolM);
 			break;
@@ -525,13 +578,15 @@ apply_usage_restrictions(char * source_type, GB * G,
 
 static
 int
-process_level_option(char * level_name)
+process_level_option(BLIST * BL, char * level_name)
 {
 	struct blist_level * list;
 	list = blist_levels_i;
 	while((*list).lv_nameM) {
 		if (strcmp((*list).lv_nameM, level_name) == 0 ) {
 			(*list).lv_is_setM = 1;
+			if (strcmp(level_name, SW_A_host))
+				BL->level_is_setM ++;
 			return 0;
 		}
 		list++;
@@ -547,7 +602,6 @@ main(int argc, char **argv)
 	int c;
 	int ret;
 	int optret = 0;
-	int dup_of_target_fdar0;
 	int target_fdar[3];
 	int source_fdar[3];
 	int target_stdio_fdar[3];
@@ -563,7 +617,6 @@ main(int argc, char **argv)
 	int ism;
 	int no_of_selections_processed;
 	int jsm;
-	char * tmp_s;
 	pid_t ss_pid = 0;
 	pid_t source_write_pid = 0;
 	pid_t target_pump_pid = 0;
@@ -574,15 +627,15 @@ main(int argc, char **argv)
 	int opt_level_is_set = 0;
 	int opt_alt_verbose = 0;
 	int opt_index_file_format = 0;  /* -v option */
+	char * attr;
+	int attr_index;
 	char * opt_catalog_dest_dir = (char *)NULL;   /* -c option */
-	char * opt_attribute = (char*)NULL;   /* -a option */
 	char * opt_option_files = (char*)NULL;
 
 	char * wopt_shell_command = (char*)(NULL);
 	char * wopt_any_format = (char*)(NULL);
 	int    wopt_no_defaults = 0;
 	int    wopt_kill_hop_threshhold = 2;  /* 2 */
-	char * wopt_enforce_sig = (char*)NULL;
 	char * wopt_no_getconf = (char*)NULL;
 	char * wopt_forward_agent = (char*)CHARTRUE;
 	char * wopt_no_remote_kill = (char*)NULL;
@@ -596,7 +649,6 @@ main(int argc, char **argv)
 	char * wopt_show_options_files = NULL;
 	char * wopt_blocksize = "5120";
 	char * wopt_sig_level;
-	char * wopt_allow_ambig;
 	char * wopt_enforce_all_signatures;
 	char wopt_pgm_mode[30];
 	char wopt_pgm_mode_explicitly_set = 0;
@@ -609,12 +661,10 @@ main(int argc, char **argv)
 	char * eopt_verbose;
 	char * response_img;
 
-	int is_seekable = 0;
 	int optionEnum;
 	int devel_no_fork_optimization = 0; /* reject the no fork optimization */
 	int local_stdin = 0;
 	int do_extension_options_via_goto = 0;
-	int tmp_status;
 	int fverfd;
 	int target_loop_count = 0;
 	int target_success_count = 0;
@@ -625,7 +675,6 @@ main(int argc, char **argv)
 	int testnum = 0;
 	int f_retval = 0;
 	int s_retval = 0;
-	int found_ambig = 0;
 	int rp_status;
 	int target_file_size;
 	unsigned long int statbytes;
@@ -637,6 +686,7 @@ main(int argc, char **argv)
 	int local_stdout_in_use = 0;
 	int reqs_failed = 0;
 	int nmatches;
+	int local_attr_mode;
 	struct extendedOptions * opta = optionsArray;
 	struct termios	*login_orig_termiosP = NULL;
 	struct winsize	*login_sizeP = NULL;
@@ -649,7 +699,6 @@ main(int argc, char **argv)
 	char * exoption_arg;
 	char * exoption_value;
 	char * catalog_entry_directory;
-	char * soc_spec_source = (char*)NULL;
 	char * cl_target_target = (char*)NULL;
 	char * new_cl_target_target = (char*)NULL;
 	char * xcl_target_target = (char*)NULL;
@@ -662,7 +711,6 @@ main(int argc, char **argv)
 	char * working_arg = (char*)NULL;
 	char * current_arg = (char*)NULL;
 	char * system_defaults_files = (char*)NULL;
-	char * source_path = (char*)NULL;
 	char cwd[1024];
 	char * remote_shell_command = REMOTE_SSH_BIN;
 	char * remote_shell_path;
@@ -674,6 +722,7 @@ main(int argc, char **argv)
 	VPLOB * ex_reqs;
 	STROB * tmp;
 	STROB * btmp2;
+	STROB * target_current_dir;
 	STROB * target_control_message;
 	STROB * target_start_message;
 	STROB * target_catalog_message;
@@ -682,7 +731,6 @@ main(int argc, char **argv)
 	STROB * target_line_buf;
 	STROB * isc_script_buf;
 	STROB * tmpcommand;
-	STROB * target_catalog_dir;
 	CPLOB * w_arglist;
 	CPLOB * e_arglist;
 	SHCMD * target_sshcmd[2];
@@ -845,6 +893,7 @@ main(int argc, char **argv)
 
 	BL = &g_blist;
 	blist_init(BL);
+	BL->levelsM = blist_levels_i;
 
 	pre_reqs = NULL;  /* used for testing, not by a published option */
 	ex_reqs = NULL;   /* used for testing, not by a published option */
@@ -901,7 +950,7 @@ main(int argc, char **argv)
 	
 	source_line_buf = strob_open(10);
 	target_line_buf = strob_open(10);
-	target_catalog_dir = strob_open(10);
+	target_current_dir = strob_open(10);
 
 	nullfd = G->g_nullfd;
 
@@ -992,9 +1041,13 @@ main(int argc, char **argv)
 
 		switch (c) {
 		case 'a':
-			strcpy(wopt_pgm_mode, SWLIST_PMODE_ATT);
-			/* wopt_pgm_mode_explicitly_set = 1; */
-			strar_add(BL->attributesM, optarg);
+			if (swuts_is_uts_attribute(optarg)) {
+				BL->has_uts_attributesM++;
+			} else {
+				BL->has_soc_attributesM++;
+				strcpy(wopt_pgm_mode, SWLIST_PMODE_ATT);
+			}
+			swlist_blist_attr_add(BL, optarg);
 			break;
 		case 'c':
 			opt_catalog_dest_dir = strdup(optarg);
@@ -1009,7 +1062,7 @@ main(int argc, char **argv)
 			break;
 		case 'l':
 			opt_level_is_set = 1;
-			if (process_level_option(optarg)) {
+			if (process_level_option(BL, optarg)) {
 				/* error */
 				sw_e_msg(G, "invalid level: %s \n", optarg);
 				LCEXIT(1);
@@ -1030,10 +1083,6 @@ main(int argc, char **argv)
 		case 'v':  /* -v is the posix option for
 				'use_index_file_format' for output */
 			opt_alt_verbose++;
-			/*
-			opt_index_file_format = 1;
-			BL->index_formatM = 1;
-			*/
 			break;
 		case 'f':
 			/* Process the selection file */
@@ -1488,10 +1537,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	/* Show the options to stdout.  */
 
 	if (wopt_show_options_files) { 
-		parse_options_files(opta, 
+		swextopt_parse_options_files(opta, 
 			system_defaults_files, 
 			progName, 1 /* not req'd */,  1 /* show_only */);
-		parse_options_files(opta, 
+		swextopt_parse_options_files(opta, 
 			opt_option_files, 
 			progName,
 		 	1 /* not req'd */,  1 /* show_only */);
@@ -1502,7 +1551,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	    if HOME is set.  */
 
 	if (wopt_no_defaults == 0) {
-		optret += parse_options_files(opta, 
+		optret += swextopt_parse_options_files(opta, 
 			system_defaults_files, 
 			progName, 
 			0 /* not req'd */,  0 /* not show_only */);
@@ -1514,7 +1563,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	
 	/*  Read the defaults files given with the -X option.  */
 
-	optret += parse_options_files(opta, 
+	optret += swextopt_parse_options_files(opta, 
 		opt_option_files, 
 		progName, 	
 		1 /* req'd */, 0 /* not show_only */);
@@ -1554,7 +1603,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	if (is_index_file_format(wopt_pgm_mode, opt_alt_verbose, wopt_pgm_mode_explicitly_set)) {
 		E_DEBUG("");
 		opt_index_file_format = 1;
-		BL->index_formatM = 1;
+		BL->index_format_is_setM = 1;
 	} else {
 		E_DEBUG("");
 		if (opt_alt_verbose) {
@@ -1655,6 +1704,7 @@ E_DEBUG3("current_arg=[%s] eopt_distribution_target_directory=[%s]", current_arg
 	E_DEBUG("");
 	while (current_arg && local_stdin == 0) {
 E_DEBUG2("current_arg=[%s]", current_arg);
+E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 		distdataO = swi_distdata_create();
 		swgp_signal(SIGINT, safe_sig_handler);
 		swgp_signal(SIGPIPE, safe_sig_handler);
@@ -1674,6 +1724,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 
 		/* Parse the target sofware_selections and targets.  */
 
+		swlist_blist_clear_all_as_processed(BL);
 		if (target_loop_count == 0) {
 
 			/* This branch really only checks for an invalid
@@ -1705,13 +1756,17 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 		} else {
 			/* subsequent args are targets, the same software
                            selection applies.  */
-
-			cl_target_target = strdup(working_arg);
+			if (*working_arg == '@')
+				cl_target_target = strdup(working_arg+1);
+			else
+				cl_target_target = strdup(working_arg);
 		}
+		E_DEBUG2("NOW cl_target_target = %s", cl_target_target);
 
 		new_cl_target_target = swc_convert_multi_host_target_syntax(G, cl_target_target);
 		free(cl_target_target);
 		cl_target_target = new_cl_target_target;
+		G->g_cl_target_targetM = strdup(cl_target_target);
 
 		/* Parse the target string and set the commands to invoke */
 
@@ -1787,7 +1842,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 		/* Policy and sanity checks for use of standard output */
 		local_stdout_in_use = 1;
 		if (
-			BL->index_formatM == 1 ||
+			BL->index_format_is_setM == 1 ||
 			strar_num_elements(BL->attributesM) > 0
 		) { 
 			local_stdout_in_use = 0;
@@ -2026,7 +2081,37 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 			}
 
 			sw_d_msg(G, "start_ctl_message(loc=start): %s\n", strob_str(target_start_message));
+
+			/*
+			 * ===============================
+			 * read the pwd current directory message
+			 * from the target
+			 * MSG_129 
+			 * ===============================
+			 */
+
+			ret = swc_read_target_message_129(G, target_fdar[0], target_current_dir, G->g_verboseG, "target pwd");
+			if (ret < 0) {
+				/* FIXME, should be bigger error than this */
+				sw_e_msg(G, "SW_INTERNAL_ERROR for target %s in file %s at line %d: message _129 failed\n",
+						current_arg, __FILE__, __LINE__);
+				goto ENTER_WITH_FAILURE;
+			}
+
+			/* Now adjust the target_path to be an absolute path
+			   if it is not already */
+
+			if (*target_path != '/') {
+				target_path = swc_make_absolute_path(strob_str(target_current_dir), target_path);
+				swicol_set_targetpath(swicol, target_path);
+			}
 			
+			if (swlib_is_sh_tainted_string(target_path)) {
+				SWLIB_FATAL("tainted path");
+			}
+
+			/* Now target_path is absolute */
+
 			if (target_nhops >= wopt_kill_hop_threshhold) {
 
 				/* Construct the remote kill vector if warranted  */
@@ -2243,59 +2328,69 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 			ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
 						SWBIS_TS_Do_nothing ": testing 123");
 
-			if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_ATT) == 0) {
-
-				/* The -a <attribute> option was used */
-
-				char * attr;
-				attr = strar_get(BL->attributesM, 0);
-				E_DEBUG("");
-				SWLIB_ASSERT(attr != NULL);
-				if (strcmp(attr, SW_A_architecture) == 0) {
-					E_DEBUG("");
-					/* write the config.guess'ed triplet to stdout,
-					   it should be sitting in uts->arch_tripletM */
-					/*
-					attr = uts->arch_tripletM ? uts->arch_tripletM : "unknown";
-					if (opt_index_file_format == 0)
-						fprintf(stdout, "%s\n", attr);
-					else
-						fprintf(stdout, "    " SW_A_architecture " %s\n", attr);
-					*/	
-					write_attr(SW_A_architecture, uts->arch_tripletM, opt_index_file_format);
-				} else if (strcmp(attr, SW_A_os_name) == 0) {
-					write_attr(SW_A_os_name, uts->sysnameM, opt_index_file_format);
-				} else if (strcmp(attr, SW_A_os_version) == 0) {
-					write_attr(SW_A_os_version, uts->versionM, opt_index_file_format);
-				} else if (strcmp(attr, SW_A_os_release) == 0) {
-					write_attr(SW_A_os_release, uts->releaseM, opt_index_file_format);
-				} else if (strcmp(attr, SW_A_machine_type) == 0) {
-					write_attr(SW_A_os_release, uts->machineM, opt_index_file_format);
-				} else {
-					sw_e_msg(G, "attribute not supported at this time: %s.\n", attr);
+			local_attr_mode = (
+				BL->has_uts_attributesM &&
+				BL->level_is_setM == 0  /* i.e. a host level only */
+					);
+			if (
+				local_attr_mode
+			) {
+				/* The -a <attribute> option was used without a -l level specification */
+				attr_index = 0;
+				E_DEBUG("at while");
+				while ((attr=swlist_blist_get_next_attr(BL, attr_index, &attr_index)) != NULL) {
+					/* attr = strar_get(BL->attributesM, 0); */
+					E_DEBUG3("attr=%s attr_index=%d", attr, attr_index);
+					SWLIB_ASSERT(attr != NULL);
+					if (strcmp(attr, SW_A_architecture) == 0) {
+						E_DEBUG("");
+						/* write the config.guess'ed triplet to stdout,
+						   it should be sitting in uts->arch_tripletM */
+						/*
+						attr = uts->arch_tripletM ? uts->arch_tripletM : "unknown";
+						if (opt_index_file_format == 0)
+							fprintf(stdout, "%s\n", attr);
+						else
+							fprintf(stdout, "    " SW_A_architecture " %s\n", attr);
+						*/	
+						swlist_write_attr2(BL, cl_target_target, SW_A_architecture, uts->arch_tripletM, attr_index);
+					} 
+	
+					if (strcmp(attr, SW_A_os_name) == 0) {
+						swlist_write_attr2(BL, cl_target_target, SW_A_os_name, uts->sysnameM, attr_index);
+					} 
+	
+					if (strcmp(attr, SW_A_os_version) == 0) {
+						swlist_write_attr2(BL, cl_target_target, SW_A_os_version, uts->versionM, attr_index);
+					} 
+	
+					if (strcmp(attr, SW_A_os_release) == 0) {
+						swlist_write_attr2(BL, cl_target_target, SW_A_os_release, uts->releaseM, attr_index);
+					} 
+	
+					if (strcmp(attr, SW_A_machine_type) == 0) {
+						swlist_write_attr2(BL, cl_target_target, SW_A_machine_type, uts->machineM, attr_index);
+					} 
+					attr_index++;
 				}
+
+				/* The required fulfillment of SWBIS_TS_Get_iscs_listing is below
+				   in the default else block of the next statement */
 				E_DEBUG("");
-				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Get_iscs_listing ": not needed");
-				if (ret != 0) {
-					swicol_set_master_alarm(swicol);
-					sw_e_msg(G, "swicol: fatal: %s:%d\n", __FILE__, __LINE__);
-				}
-			} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_CAT) == 0) {
+			} 
+
+			if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_CAT) == 0) {
 				/* This is the code path for the -c DIR option.
 				   Write a tar archive of the catalog to stdout */
 
 				swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 
-				swicat_write_isc_script(isc_script_buf, G, swspecs, NULL, NULL, NULL,
-					target_path, SWICAT_FORM_TAR1);
-				strob_strcpy(target_catalog_dir, target_path);
-				swlib_unix_dircat(target_catalog_dir, get_opta_isc(opta, SW_E_installed_software_catalog));
+				swicat_write_isc_script(isc_script_buf, G, swspecs, NULL, NULL, NULL, SWICAT_FORM_TAR1);
 				/* swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing); */
 				ret = swicol_rpsh_task_send_script2(swicol,
 					target_fdar[1],			/* file descriptor of the task shell's stdin */
 					512,				/* data size, here just a gratuitous block of NULs */
-					strob_str(target_catalog_dir),	/* Directory to run in */
+					target_path,			/* Directory to run in */
 					strob_str(isc_script_buf),	/* The actual script */
 					SWBIS_TS_Get_iscs_listing);
 				if (ret != 0) {
@@ -2335,9 +2430,13 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				ret = swicol_rpsh_task_expect(swicol, G->g_swi_event_fd, SWICOL_TL_4);
 				E_DEBUG("done");
 
-			} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) == 0) {
-				/* This section will list the files in installed software */	
+			} else if (
+				swlist_has_annex_attribute(BL) ||
+				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) == 0 ||
+				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) == 0
+			) {
 
+				/* This section will list the files in installed software */	
 
 				/* Sample abort code (for reference)
 				sw_e_msg(G, "file listing for installed software not yet implemented\n");
@@ -2351,6 +2450,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				 * ===========================================================
 				 * ===========================================================
 				 */
+				E_DEBUG("SWLIST_PMODE_FILE");
 
 				if (! does_have_sw_selections(swspecs)) {
 					E_DEBUG("No selections given on command line");
@@ -2415,6 +2515,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				/* loop over the queries, which are actually the whitespace delimited
 				   software selections from the command line */
 
+				E_DEBUG("Loop over selections");
 				while (
 					/* s_retval == 0 && */
 					f_retval == 0 &&
@@ -2426,7 +2527,9 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 					jsm = 0;
 					no_of_selections_processed++;
 					nmatches = sc_selections_check(G, opta, sc);
+					E_DEBUG("while (sc=vplob_val(sl->scM, ism++)");
 					if (nmatches == 0) {
+						E_DEBUG("SW_SELECTION_NOT_FOUND");
 						strob_sprintf(btmp2, 0,
 							"SW_SELECTION_NOT_FOUND on %s: %s: status=1\n",
 								cl_target_target, sc->sqM->swspec_stringM);
@@ -2443,6 +2546,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 						G->g_signal_flag == 0 &&
 						1
 					) {
+						swlist_blist_clear_all_as_processed(BL);
 						critical_region_begin();
 						E_DEBUG2("START OF RESPONSE for %s", swverid_print(sr->swspecM, NULL));
 						E_DEBUG("");
@@ -2453,14 +2557,14 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 						rp_status = 1;
 						E_DEBUG("");
 						E_DEBUG2("signal_flag=%d", G->g_signal_flag);
-						ret = swlist_looper_sr_payload(G, target_path, swicol,
+						ret = swlist_looper_sr_payload(G, BL, target_path, cl_target_target, swicol,
 									sr,
 									target_fdar[1],
 									target_fdar[0],
 									&rp_status,
 									uts,
 									pax_write_command_key,
-									wopt_file_sys);
+									wopt_file_sys, wopt_pgm_mode);
 
 						/* rp_status is the script return status
 						   ret, if non-zero is a protocol or internal error */
@@ -2538,7 +2642,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_DIR) == 0 ||
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_DEP1) == 0 
 			) {
-				E_DEBUG("");
+				E_DEBUG("SWLIST_PMODE_PROD SWLIST_PMODE_DIR SWLIST_PMODE_DEP1");
 				ret = swpl_do_list_catalog_entries2(G,
 						swspecs, pre_reqs, NULL, ex_reqs,
 						target_path,
@@ -2555,20 +2659,22 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				} else {
 					reqs_failed = 0;
 				}
-			} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) == 0) {
-				E_DEBUG("");
-				sw_e_msg(G, "software definition file format list mode unsupported\n");
-				swicol_set_master_alarm(swicol);
-				swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
-				abort_script(swicol, G, target_fdar[1]);
-				ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
 			} else {
-				E_DEBUG("");
-				sw_e_msg(G, "unsupported mode\n");
-				swicol_set_master_alarm(swicol);
-				swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
-				abort_script(swicol, G, target_fdar[1]);
-				ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
+				if (local_attr_mode) {
+					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Get_iscs_listing ": not needed");
+					if (ret != 0) {
+						swicol_set_master_alarm(swicol);
+						sw_e_msg(G, "swicol: fatal: %s:%d\n", __FILE__, __LINE__);
+					}
+				} else {
+					E_DEBUG("");
+					sw_e_msg(G, "unsupported mode\n");
+					swicol_set_master_alarm(swicol);
+					swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
+					abort_script(swicol, G, target_fdar[1]);
+					ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
+				}
 			}
 			if (G->g_do_debug_events)
 				swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
