@@ -1,6 +1,6 @@
 /* swlist_lib.c -- swlist routines.
 
- Copyright (C) 2006,2007,2008 James H. Lowe, Jr. 
+ Copyright (C) 2006,2007,2008,2010 James H. Lowe, Jr. 
  All Rights Reserved.
  
  COPYING TERMS AND CONDITIONS:
@@ -51,6 +51,19 @@
 #include "shlib.h"
 #include "ls_list.h"
 
+int
+is_annex_attribute(char * name)
+{
+	if (
+		strcmp(name, SW_A_mod_date) &&
+		strcmp(name, SW_A_create_date) &&
+		strcmp(name, SW_A_software_spec)
+	)
+		return 0;
+	else
+		return 1;
+}
+
 static
 void
 looper_abort(GB * G, SWICOL * swicol, int ofd)
@@ -58,6 +71,39 @@ looper_abort(GB * G, SWICOL * swicol, int ofd)
 	swpl_send_abort(swicol, ofd, G->g_swi_event_fd,  SWBIS_TS_Abort);
 }
 
+static
+char *
+get_attribute_from_installed(BLIST * BL, SWICAT_E * e, char * object, char * keyword)
+{
+	int parse_status;
+	int swlex_inp;
+	char * parser_line;
+	SWHEADER_STATE state_wid;
+	SWHEADER * isf_header;
+	SWVERID * wid;
+
+	E_DEBUG("");
+	if (BL->isf_headerM) {
+		isf_header = BL->isf_headerM;	
+		swheader_store_state(isf_header, &state_wid);
+		swheader_reset(isf_header);
+	} else {
+		swlex_inp = swlex_get_input_policy();
+		swlex_set_input_policy(SWLEX_INPUT_UTF_TR);
+		isf_header = swicat_e_isf_parse(e, &parse_status, NULL);
+		swlex_set_input_policy(swlex_inp);
+		if (parse_status)
+			return NULL;
+		swheader_store_state(isf_header, &state_wid);
+		BL->isf_headerM = isf_header;
+	}
+	wid = swverid_open(object, (char*)(NULL));
+	swverid_get_object_by_swverid(isf_header, wid,  (int*)NULL);
+	parser_line = swheader_get_attribute_in_current_object(isf_header, keyword, NULL, NULL);
+	swheader_restore_state(isf_header, &state_wid);
+	return parser_line;
+}
+
 static
 int
 show_nopen(void)
@@ -69,6 +115,29 @@ show_nopen(void)
 	close(ret);
 	return ret;
 }
+	
+static
+void
+write_attributes(BLIST * BL, STROB * buf, SWHEADER * swheader, int index)
+{
+	char * line;
+	int level;
+	char * keyword;
+	char * value;
+
+	E_DEBUG("");
+	swheader_store_state(swheader, NULL);
+	swheader_set_current_offset(swheader, index);
+	while((line=swheader_get_next_attribute(swheader))) {
+		E_DEBUG("");
+		keyword = swheaderline_get_keyword(line);
+		value = swheaderline_get_value(line, (int *)NULL);
+		level = swheaderline_get_level(line);
+		swdef_write_keyword_to_buffer(buf, keyword, level, SWPARSE_MD_TYPE_ATT);
+		swdef_write_value_to_buffer(buf, value);
+	}
+	swheader_restore_state(swheader, NULL);
+}
 
 static
 char *
@@ -136,7 +205,132 @@ looper_locked_region(STROB * buf, int vlv)
 	return strob_str(buf);
 }
 
-int /* Deprecated, see swpl_ls_fileset_from_iscat() in swproglib.c */
+static
+int
+write_index_format_from_iscat(GB * G, SWI * swi, SWICAT_E * e, BLIST * BL, int ofd, int ls_verbose)
+{
+	int retval;
+	int index;
+	int parse_status;
+	int swlex_inp;
+	int ret;
+	char * next_line;
+	char * keyword;
+	char * value;
+	char * hline;
+	char * dist_description;
+	char * dist_title;
+	
+	SWHEADER_STATE info_state1;
+	SWHEADER_STATE state1;
+	SWHEADER_STATE state_dist_wid;
+	SWHEADER * global_dist_index_header;
+	SWHEADER * info_header;
+	SWHEADER * isf_header;
+	SWI_PRODUCT * current_product;
+	SWI_XFILE * current_fileset;
+	STROB * ls_line;
+	STROB * buf;
+	SWVERID * dist_wid;
+
+	E_DEBUG("");
+	retval = 0;
+	ls_line = strob_open(60);
+	buf = strob_open(60);
+
+	/* FIXME: Eventually support multiple products and filesets  */
+
+	swpl_enforce_one_prod_one_fileset(swi);
+
+	/* Get the current product and fileset, for now, the first ones */
+
+	current_product = swi_package_get_product(swi->swi_pkgM, 0 /* the first one */);
+	current_fileset = swi_product_get_fileset(current_product, 0 /* the first one */);
+
+	global_dist_index_header = swi_get_global_index_header(swi);
+
+	/* Loop over the INFO file definitions, these are found
+		in the SWHEADER for the fileset */
+
+	info_header = swi_get_fileset_info_header(swi, 0, 0); /* FIXME */
+	swheader_store_state(info_header, &info_state1);
+	swheader_reset(info_header);
+
+	/* Create the SWHEADER of the INSTALLED file
+	*/
+	swlex_inp = swlex_get_input_policy();
+	swlex_set_input_policy(SWLEX_INPUT_UTF_TR);
+
+	E_DEBUG("");
+	isf_header = swicat_e_isf_parse(e, &parse_status, NULL);
+	swlex_set_input_policy(swlex_inp);
+
+	swheader_reset(global_dist_index_header);
+	dist_wid = swverid_open(SW_A_distribution, (char*)(NULL));
+	swverid_get_object_by_swverid(global_dist_index_header, dist_wid,  (int*)NULL);
+	swheader_store_state(global_dist_index_header, &state_dist_wid);
+
+	dist_description = swheader_get_attribute_in_current_object(global_dist_index_header, SW_A_description, NULL, NULL);
+	swheaderline_write_to_buffer(buf,  dist_description);
+
+	dist_title = swheader_get_attribute_in_current_object(global_dist_index_header, SW_A_title, NULL, NULL);
+	swheaderline_write_to_buffer(buf,  dist_title);
+
+	if (!isf_header) {
+		E_DEBUG("HERE");
+		sw_e_msg(G, "error parsing INSTALLED file\n");
+		return -1;
+	} 
+
+	/* write the installed_software information in INDEX in format */
+	
+	E_DEBUG("");
+	while ((next_line=swheader_get_next_object(isf_header, (int)UCHAR_MAX, (int)UCHAR_MAX))) {
+
+		E_DEBUG2("next_line=%s", next_line);
+		if (swheaderline_get_type(next_line) != SWPARSE_MD_TYPE_OBJ) {
+			/* Sanity check */
+			SWBIS_IMPL_ERROR_DIE(1);
+		}
+		keyword = swheaderline_get_keyword(next_line);
+		value = swheaderline_get_value(next_line, (int*)(NULL));
+		swheaderline_write (next_line, ofd);
+		strob_strcpy(buf, "");
+		
+		index = swheader_get_current_offset(isf_header);
+		write_attributes(BL, buf, isf_header, index);
+		uxfio_write(ofd, strob_str(buf), strob_strlen(buf));
+       	}
+
+	/* write the INFO in index format */
+
+	while ((next_line=swheader_get_next_object(info_header, (int)UCHAR_MAX, (int)UCHAR_MAX))) {
+
+		E_DEBUG2("next_line=%s", next_line);
+		if (swheaderline_get_type(next_line) != SWPARSE_MD_TYPE_OBJ) {
+			/* Sanity check */
+			SWBIS_IMPL_ERROR_DIE(1);
+		}
+		keyword = swheaderline_get_keyword(next_line);
+		value = swheaderline_get_value(next_line, (int*)(NULL));
+		swheaderline_write (next_line, ofd);
+		strob_strcpy(buf, "");
+		
+		index = swheader_get_current_offset(info_header);
+		write_attributes(BL, buf, info_header, index);
+		uxfio_write(ofd, strob_str(buf), strob_strlen(buf));
+       	}
+
+
+	swheader_reset(global_dist_index_header);
+	swheader_restore_state(info_header, &info_state1);
+	strob_close(buf);
+	strob_close(ls_line);
+	return retval;
+}
+
+static
+int
 ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose)
 {
 	int retval;
@@ -146,9 +340,7 @@ ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose)
 	SWI_PRODUCT * current_product;
 	SWI_XFILE * current_fileset;
 	char * next_line;
-	char * next_attr;
 	char * keyword;
-	char * value;
 	AHS * info_ahs2;
 	int ret;
 	STROB * ls_line;
@@ -226,6 +418,79 @@ ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose)
 	return retval;
 }
 
+static
+void
+write_annex_date_attribute (GB * G, SWICAT_E * e, BLIST * BL, char * cl_target_target, int attr_index, char * installed_kw, char * attr_name)
+{
+	char * line;
+	char * value;
+	unsigned long int uli;
+	char buf[30];
+	int result;
+	time_t tm;
+
+	E_DEBUG("");
+	line = get_attribute_from_installed(BL, e, SW_A_product, installed_kw);
+	if (!line) goto error_out;
+	value = swheaderline_get_value(line, (int *)NULL);
+	if (!value) goto error_out;
+    	uli = swlib_atoul(value, &result);
+	tm = (time_t)uli;
+	/* ctime_r(&tm, buf); */
+        strncpy(buf, asctime(localtime(&tm)), sizeof(buf) - 1);
+        buf[sizeof(buf)-1] = '\0';
+	swlib_tr(buf, (int)'\0', (int)'\r');
+	swlib_tr(buf, (int)'\0', (int)'\n');
+	swlist_write_attr2(BL, cl_target_target, attr_name, buf, attr_index);
+	E_DEBUG("");
+	return;
+	error_out:
+	sw_e_msg(G, "error parsing INSTALLED file while searching for attribute: %s\n", SW_A_create_time);
+
+}
+
+static
+int
+write_annex_attributes (GB * G, SWICAT_E * e, BLIST * BL, char * cl_target_target, SWICAT_SR * sr)
+{
+	int attr_index;
+	char * attr;
+	char * line;
+	char * value;
+
+	attr_index = 0;
+	while ((attr=swlist_blist_get_next_attr(BL, attr_index, &attr_index)) != NULL) {
+		if (strcmp(attr, SW_A_create_date) == 0) {
+			write_annex_date_attribute (G, e, BL, cl_target_target, attr_index, SW_A_create_time, SW_A_create_date);
+		} 
+
+		if (strcmp(attr, SW_A_mod_date) == 0) {
+			write_annex_date_attribute (G, e, BL, cl_target_target, attr_index, SW_A_mod_time, SW_A_mod_date);
+		} 
+
+		if (strcmp(attr, SW_A_software_spec) == 0) {
+			swlist_write_attr2(BL, cl_target_target, SW_A_software_spec, swverid_print(sr->swspecM, NULL), attr_index);
+		} 
+		attr_index++;
+	}
+	return 0;
+}
+
+void
+swlist_write_attr2(BLIST * BL, char * host, char * name, char * value, int attr_index)
+{
+	static STROB * buffer;
+
+	if (!buffer) buffer = strob_open(20);
+	if (! value) value = "\"\"";
+	if (swlist_blist_level_is_set(BL, SW_LEVEL_V_HOST)) {
+		swlib_writef(STDOUT_FILENO, buffer, "%s: %s: %s\n", host, name, value);
+	} else {
+		swlib_writef(STDOUT_FILENO, buffer, "%s: %s\n", name, value);
+	}
+	swlist_blist_mark_as_processed(BL, attr_index);
+}
+
 int
 swlist_write_source_copy_script2(GB * G,
 	int ofd, 
@@ -358,7 +623,6 @@ swlist_write_source_copy_script2(GB * G,
 
 	strob_sprintf(isc_msg, 0, "installed catalog at %s", get_opta_isc(G->optaM, SW_E_installed_software_catalog));
 
-
 	/* Make a final adjustment if the path is '/', FIXME */
 	if (
 		strcmp(basename, "/") == 0 &&
@@ -380,13 +644,16 @@ swlist_write_source_copy_script2(GB * G,
 	strob_sprintf(buffer_new, STROB_DO_APPEND,
 	/* ret = swlib_writef(ofd, buffer,  */
 									/* ism_begin */
+		"IFS=\"`printf ' \\t\\n'`\"\n"
 		"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 		"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+		"echo " SWBIS_TARGET_CTL_MSG_129 ": \"`pwd | head -1`\"\n"
 		"export LOCKENTRY\n"
 		CSHID
 		"LOCKPATH=\"\"\n"
 		"%s\n"  			/* SEVENT: SW_SESSION_BEGINS */
 		"%s" 				/* swicol_subshell_marks */
+		"wcwd=\"`pwd`\"\n"
 		"export lock_did_lock\n"
 		"export opt_force_lock\n"
 		"lock_did_lock=\"\"\n"
@@ -395,7 +662,7 @@ swlist_write_source_copy_script2(GB * G,
 		"export PATH\n"
 		"PATH=`getconf PATH`:$PATH\n"
 		"export swutilname\n"
-		"swutilname=swinstall\n"
+		"swutilname=swlist\n"
 		"%s\n"			/* shls_bashin2 from shell_lib.sh */
 		"%s\n"			/* shls_false_ from shell_lib.sh */
 		"%s\n"			/* shls_looper from  shell_lib.sh */
@@ -404,6 +671,7 @@ swlist_write_source_copy_script2(GB * G,
 		"%s\n"			/* lf_ lock routine */
 		"%s\n"			/* lf_ lock routine */
 		"%s\n"			/* lf_ lock routine */
+		"%s\n"			/* shls_make_dir_absolute */
 		"%s" 			/* set statement for verbosity */
 		"pgm_mode=\"%s\"\n"
 		"blocksize=\"%s\"\n"
@@ -411,6 +679,43 @@ swlist_write_source_copy_script2(GB * G,
 		"basename=\"%s\"\n"
 		"targetpath=\"%s\"\n"
 		"sourcepath=\"%s\"\n"
+
+		"#\n"
+		"# make sourcepath absolute\n"
+		"#\n"
+		"case \"$sourcepath\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$sourcepath\"\n"
+		"shls_make_dir_absolute\n"
+		"sourcepath=\"$mda_target_path\"\n"
+		"# sourcepath is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make absolute\n"
+		"#\n"
+
+		"#\n"
+		"# make dirname absolute\n"
+		"#\n"
+		"case \"$dirname\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$dirname\"\n"
+		"shls_make_dir_absolute\n"
+		"dirname=\"$mda_target_path\"\n"
+		"# dirname is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make absolute\n"
+		"#\n"
+
 		"sw_targettype=unset\n"
 		"sw_retval=0\n"
 		"sb__delaytime=%d\n"
@@ -511,7 +816,7 @@ swlist_write_source_copy_script2(GB * G,
 		"swexec_status=$sw_retval\n"
 
 		"		case \"$pgm_mode\" in\n"
-		"		" SWLIST_PMODE_FILE ")\n"	
+		"		" SWLIST_PMODE_FILE "|" SWLIST_PMODE_INDEX "|" SWLIST_PMODE_ATT ")\n"	
 		"			shls_looper \"$sw_retval\"\n"
 		"			sw_retval=$?\n"
 		"			swexec_status=$sw_retval\n"
@@ -555,6 +860,7 @@ swlist_write_source_copy_script2(GB * G,
 /*_% 10 */	shlib_get_function_text_by_name("lf_make_lockfile_entry", shell_lib_buf, NULL),
 /*_% */		shlib_get_function_text_by_name("lf_test_lock", shell_lib_buf, NULL),
 /*_% */		shlib_get_function_text_by_name("lf_remove_lock", shell_lib_buf, NULL),
+/*_% */		shlib_get_function_text_by_name("shls_make_dir_absolute", shell_lib_buf, NULL),
 /*_% */		strob_str(set_vx),
 /*_% */		pgm_mode,
 /*_% */		blocksize,
@@ -629,6 +935,25 @@ swlist_write_source_copy_script2(GB * G,
 	return !(ret > 0);
 }
 
+int
+swlist_has_annex_attribute(BLIST * BL)
+{
+	char * attr;
+	int attr_index;
+	
+	E_DEBUG("");
+	attr_index = 0;
+	while ((attr=swlist_blist_get_next_attr(BL, attr_index, &attr_index)) != NULL) {
+		if (is_annex_attribute(attr)) {
+			E_DEBUG("returning 1");
+			return 1;
+		}
+		attr_index++;
+	}
+	E_DEBUG("returning 0");
+	return 0;
+}
+
 SWI *
 swlist_list_create_swi(GB * G,
 	struct extendedOptions * opta,
@@ -762,27 +1087,29 @@ swlist_list_distribution_archive(
 
 
 	if (0) {
+		/* dead code */
 		E_DEBUG("");
 		/* This lists from the storage section */
+		/* 
 		ret = swinstall_arfinstall(G,
 				swi,
 				G->g_nullfd,
-				efd, /* G->g_t_efd, */
+				efd, / * G->g_t_efd, * /
 				&G->g_signal_flag,
 				target_path,
 				"",
 				swspecs,
 				SWI_SECTION_BOTH,
 				-1,
-				1, /* opt_preview */
+				1, / * opt_preview * /
 				pax_read_command_key,
 				G->g_opt_alt_catalog_root,
 				G->g_save_fdar[2],
 				opta,
 				&G->g_logspec,
-				0, /*keep_old_files*/
-				NULL /* prorgess meter */);
-	
+				0, / *keep_old_files* /
+				NULL / * prorgess meter * /);
+		*/	
 		E_DEBUG2("swinstall_arfinstall returned %d", ret);
 		if (ret) retval = -3;
 	} else {
@@ -811,27 +1138,32 @@ void
 blist_init(BLIST * blist)
 {
 	blist->attributesM = strar_open();
+	blist->attr_flagsM = strob_open(12);
 	blist->do_get_create_dateM = 0;
 	blist->do_get_mod_dateM = 0;
 	blist->do_get_software_specM = 0;
 	blist->catalogM = NULL;	
 	blist->levelsM = blist_levels_i; /* from swlist.h */
-	blist->index_formatM = 0;
+	blist->index_format_is_setM = 0;
+	blist->level_is_setM = 0;
+	blist->has_soc_attributesM = 0;
+	blist->has_uts_attributesM = 0;
+	blist->isf_headerM = NULL;
 }
 
 int
-swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
+swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_target_target, SWICOL * swicol,
 		SWICAT_SR * sr, int ofd, int ifd, int * p_rp_status,
-		SWUTS * uts, char * pax_write_command_key, int wopt_file_sys)
+		SWUTS * uts, char * pax_write_command_key, int wopt_file_sys, char * wopt_pgm_mode)
 {
 	int retval;
 	int rstatus;
 	int ret;
 	int do_skip_entry;
 	int ls_verbose;
-	int compare_status;
 	int result;
 	int sig_level;
+	int swlex_inp;
 	char * pax_read_command;
 	char * epath;
 	char * installed_software_catalog;
@@ -923,9 +1255,9 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 
 	/* Make a session lock */
 
-	E_DEBUG("");
+	E_DEBUG2("target_path=%s", target_path);
 	ret = swpl_session_lock(G, swicol, target_path, ofd, G->g_swi_event_fd);
-	E_DEBUG2("ret=%d", ret);
+	E_DEBUG2("swpl_session_lock: ret=%d", ret);
 	sw_d_msg(G, "swpl_session_lock returned [%d]\n", ret);
 
 	E_DEBUG2("swpl_session_lock returned %d", ret);
@@ -1052,7 +1384,7 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	E_DEBUG("");
 	ret = 0;
 	if (sig_level >= 0)
-		ret = swpl_signature_policy_accept(G, swgpg, G->g_verboseG, strob_str(swspec_string));
+		ret = swpl_signature_policy_accept(G, swgpg, (G->g_verboseG > 0) ? G->g_verboseG-1:0, strob_str(swspec_string));
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 	E_DEBUG2("ret=%d", ret);
 	if (ret != 0) {
@@ -1076,7 +1408,15 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 	E_DEBUG("");
+
+	swlex_inp = swlex_get_input_policy();
+	E_DEBUG("");
+	swlex_set_input_policy(SWLEX_INPUT_UTF_TR);
+	E_DEBUG("");
+
 	swi = swicat_e_open_swi(ee);
+	E_DEBUG("");
+	swlex_set_input_policy(swlex_inp);
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 	if (swi == NULL) {
 		/* swi might be NULL due to file system permission,
@@ -1203,6 +1543,7 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	if (
 		G->g_opt_previewM ||
 		do_skip_entry ||
+		swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) != 0 ||
 		0
 	) {
 		E_DEBUG("NOT running swpl_retrieve_files");
@@ -1256,26 +1597,46 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	E_DEBUG("");
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 
-	/* --------------------------------------------------*/
-	/* Now, read the payload which is a tar archive      */
-	/* --------------------------------------------------*/
+	if (
+		swlist_has_annex_attribute(BL) && /* has create_date create_time or software_spec */
+		swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) != 0 /* not index mode */
+	) {
+		/* annex attributes and not '-v' mode */
+		write_annex_attributes (G, ee, BL, cl_target_target, sr);
+		ret = 0;
 
-	E_DEBUG2("LOWEST FD=%d", show_nopen());
-	if (wopt_file_sys) {
-		E_DEBUG("List files from file system (above)");
-		/* see swpl_retrieve_files() invocation above */
-		;
-	} else {
-		/* List file from the installed catalog */
-	
-		/* swpl_show_file_list(G, file_list); */
-		if (do_skip_entry == 0) {
-			E_DEBUG("List files from installed catalog");
-			ret = ls_fileset_from_iscat(swi, STDOUT_FILENO, ls_verbose);
-		} else {
-			;
-			E_DEBUG("skipping listing files from installed catalog");
+	} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) == 0) {
+		E_DEBUG2("LOWEST FD=%d", show_nopen());
+		E_DEBUG("SWLIST_PMODE_INDEX");
+		/* sw_e_msg(G, "software definition file format (-v mode) mode unsupported\n"); */
+
+		ret = write_index_format_from_iscat(G, swi, ee, BL, STDOUT_FILENO, ls_verbose);
+		if (ret != 0) {
+			sw_e_msg(G, "error writing index format\n");
 		}
+	} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) == 0) {
+		E_DEBUG2("LOWEST FD=%d", show_nopen());
+		E_DEBUG("SWLIST_PMODE_FILE");
+		if (wopt_file_sys) {
+			E_DEBUG("List files from file system (above)");
+			/* see swpl_retrieve_files() invocation above */
+			;
+		} else {
+			/* List file from the installed catalog */
+		
+			/* swpl_show_file_list(G, file_list); */
+			if (do_skip_entry == 0) {
+				E_DEBUG("List files from installed catalog");
+				ret = ls_fileset_from_iscat(swi, STDOUT_FILENO, ls_verbose);
+			} else {
+				;
+				E_DEBUG("skipping listing files from installed catalog");
+			}
+		}
+	} else {
+		/* program internal errro */
+		/* never happens */
+		SWLIB_FATAL("");
 	}
 
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
@@ -1345,3 +1706,64 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	E_DEBUG("");
 	return retval;
 }
+
+void
+swlist_blist_attr_add(BLIST * BL, char * attr)
+{
+	int n;
+	n = strar_num_elements(BL->attributesM);
+	strar_add(BL->attributesM, attr);
+	strob_chr_index(BL->attr_flagsM, n, '\x00');
+}
+
+char * 
+swlist_blist_get_next_attr(BLIST * BL, int start, int * px)
+{
+	char * ret;
+	int f;
+	int i;
+	int n;
+	i = start;
+
+	n = strar_num_elements(BL->attributesM);
+	do {
+		f = strob_get_char(BL->attr_flagsM, i++);
+	} while (f && i < n);
+	if (!f) {
+		ret = strar_get(BL->attributesM, --i);
+		if (px) *px = i;
+	} else {
+		ret = NULL;
+	}
+	return ret;
+}
+
+void
+swlist_blist_mark_as_processed(BLIST * BL, int index)
+{
+	strob_chr_index(BL->attr_flagsM, index, '\x01');
+}
+
+void
+swlist_blist_clear_all_as_processed(BLIST * BL)
+{
+	int i;
+	int n;
+	i = 0;
+	n = strar_num_elements(BL->attributesM);
+	do {
+		strob_chr_index(BL->attr_flagsM, i++, '\x00');
+	} while (i < n);
+	if (BL->isf_headerM) {
+		swheader_close(BL->isf_headerM);
+		BL->isf_headerM = NULL;
+	}
+}
+
+int
+swlist_blist_level_is_set(BLIST * BL, int level)
+{
+	struct blist_level * list;
+	list = BL->levelsM;
+	return list[level].lv_is_setM;
+}
