@@ -41,19 +41,25 @@
 #endif
 
 struct blist_level { /* See static array in swlist.h */
-	int lv_is_setM;
-	int lv_valueM;
-	char * lv_nameM;
+	int lv_is_setM;   /* level is set of this object */
+	int lv_valueM;    /* level value */
+	char * lv_nameM;  /* level name */
 };
 
+
 typedef struct {
 	STRAR * attributesM;      /* List of '-a' option args */
+	STROB * attr_flagsM;      /* flags for the list of attributes, one-for-one */
 	int do_get_create_dateM;     /* special option arg for '-a' option is set */
 	int do_get_mod_dateM;        /* special option arg for '-a' option is set */
 	int do_get_software_specM;   /* special option arg for '-a' option is set */
 	char * catalogM;          /* '-c' option arg */
 	struct blist_level * levelsM;   /* '-l'  level settings */
-	int index_formatM;        /* '-v' option is set */
+	int index_format_is_setM;        /* '-v' option is set */
+	int level_is_setM;        /* a '-l' option has been set, other than host level */
+	int has_soc_attributesM;    /* -a  attr specified other than uts host attributes */
+	int has_uts_attributesM;    /* -a  attr specified that are uts host attributes */
+	SWHEADER * isf_headerM;
 } BLIST;
 
 void blist_init(BLIST * blist);
@@ -71,8 +77,16 @@ int swlist_list_distribution_archive(GB * G, struct extendedOptions * opta,
 SWI * swlist_list_create_swi(GB * G, struct extendedOptions * opta, VPLOB * swspecs, char * target_path);
 
 int
-swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
+swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_target_target, SWICOL * swicol,
 		SWICAT_SR * sr, int ofd, int ifd, int * p_rp_status,
-		SWUTS * uts, char * pax_write_command_key, int wopt_file_sys);
+		SWUTS * uts, char * pax_write_command_key, int wopt_file_sys, char * wopt_pgm_mode);
+void swlist_blist_attr_add(BLIST * BL, char * attr);
+char * swlist_blist_get_next_attr(BLIST * BL, int start, int * px);
+
+void swlist_blist_mark_as_processed(BLIST * BL, int index);
+void swlist_blist_clear_all_as_processed(BLIST * BL);
+int swlist_blist_level_is_set(BLIST * BL, int level);
+int swlist_has_annex_attribute(BLIST * BL);
+void swlist_write_attr2(BLIST * BL, char * host, char * name, char * value, int attr_index);
 
 #endif
