@@ -59,6 +59,7 @@
 #define SWLIST_PMODE_CAT	"list_catalog"
 #define SWLIST_PMODE_INDEX	"INDEX"   /* POSIX -v mode */
 #define SWLIST_PMODE_ATT	"ATT"   /* POSIX -a mode */
+#define SWLIST_PMODE_UTS_ATT	"ATT"   /* POSIX -a mode for uts attributes only */
 
 
 /* CISFBA base array, this should eventually replace
@@ -323,5 +324,8 @@ CISF_BASE * swpl2_cisf_base_array_get(CISF_PRODUCT * cisf, int ix);
 int swpl_run_make_installed_live(GB * G, SWI * swi, int ofd, char * target_path);
 int swpl_load_single_status_value (GB * G, SWI * swi, int ofd, int event_fd, char * id_str, int status_msg);
 int swpl2_normalize_configure_script_results(SWI * swi, char * script_name, CISF_PRODUCT * cisf);
+void swpl_print_file_list_to_buf(SWI_FILELIST * fl, STROB * buf);
+int swpl_run_check_overwrite(GB * G, SWI_FILELIST * fl, SWI * swi, int ofd, char * target_path, int mem_fd);
+void swpl_write_chdir_catalog_fragment(STROB * tmp, char * catalog_path, char * id_str);
 
 #endif
