@@ -177,47 +177,6 @@ looper_abort(GB * G, SWICOL * swicol, int ofd)
 	swpl_send_abort(swicol, ofd, G->g_swi_event_fd,  SWBIS_TS_Abort);
 }
 
-static  /* same as in swproglib.c */
-int
-check_here_document_word(SWI_FILELIST * fl, char * stop_word)
-{
-	char * name;
-	int ix;
-
-	E_DEBUG("");
-	ix = 0;
-	while ((name=swi_fl_get_path(fl, ix)) != NULL) {
-		if (strcmp(stop_word, name) == 0) {
-			return 0;
-		}
-		ix++;
-	}
-	E_DEBUG("");
-	return 1;
-}
-
-static  /* same as in swproglib.c */
-int
-determine_here_document_stop_word(SWI_FILELIST * fl, STROB * buf)
-{
-	int ret;
-	int n;
-	n = 0;
-	E_DEBUG("");
-	do {
-		strob_set_length(buf, L_tmpnam+1);		
-		tmpnam(strob_str(buf));
-		ret = check_here_document_word(fl, strob_str(buf));
-		if (ret != 0) {
-			E_DEBUG("");
-			return 0;
-		}	
-		n++;
-	} while (ret == 0 && n < 10);
-	E_DEBUG("");
-	return 1; /* error */
-}
-
 
 static  /* same as in swproglib.c */
 int
@@ -326,7 +285,6 @@ inl_get_name_len(char * line)
 	int ret;
 	int status;
 	char * s;
-	char * l;
 	/* E_DEBUG2("LINE: [%s]", line); */
 	s = strstr(line,  LS_LIST_NAME_LENGTH);
 	if (!s) {
@@ -364,7 +322,6 @@ inl_get_linkname(char * line, int * plen)
 {
 	int len;
 	char * s;
-	int ret;
 	int status;
 	int linknamelen;
 
@@ -443,7 +400,6 @@ int
 inl_is_regfile(char * line)
 {
 	char * s;
-	int ret;
 	int len;
 	E_DEBUG2("LINE: [%s]", line);
 	s = inl_get_permissions(line, &len);
@@ -460,7 +416,6 @@ inl_get_ownernames(char * line, int * plen)
 	int len;
 	int status;
 	char * ret;
-	char * e;
 	char * s;
 
 	E_DEBUG2("LINE: [%s]", line);
@@ -624,7 +579,6 @@ int
 determine_inl_field_condition(INFOLINE * info_inl, INFOLINE * syst_inl, int offset)
 {
 	int ret;
-	INFOLINE * status_inl;
 	INFOITEM * ti = (INFOITEM*)(((char*)info_inl)+offset);
 	INFOITEM * ts = (INFOITEM*)(((char*)syst_inl)+offset);
 
@@ -941,7 +895,6 @@ compare_fileset(GB * G, STROB * rpt_diff, STROB * rpt_summary, SWI * swi, int ar
 	int available_attributes;
 	int meta_fd;
 	int sys_fd;
-	char * s;
 	char * meta_text;
 	char * sys_text;
 	STRAR * sys_str;
@@ -1283,13 +1236,16 @@ swverify_write_source_copy_script2(GB * G,
 	/* ret = swlib_writef(ofd, buffer,  */
 	strob_sprintf(buffer_new, STROB_DO_APPEND,
 									/* ism_begin */
+		"IFS=\"`printf ' \\t\\n'`\"\n"
 		"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 		"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+		"echo " SWBIS_TARGET_CTL_MSG_129 ": \"`pwd | head -1`\"\n"
 		"export LOCKENTRY\n"
 		CSHID
 		"LOCKPATH=\"\"\n"
 		"%s\n"  			/* SEVENT: SW_SESSION_BEGINS */
 		"%s" 				/* swicol_subshell_marks */
+		"wcwd=\"`pwd`\"\n"
 		"export lock_did_lock\n"
 		"export opt_force_lock\n"
 		"export swbis_ignore_scripts\n"
@@ -1309,6 +1265,7 @@ swverify_write_source_copy_script2(GB * G,
 		"%s\n"			/* lf_ lock routine */
 		"%s\n"			/* lf_ lock routine */
 		"%s\n"			/* lf_ lock routine */
+		"%s\n"			/* shls_make_dir_absolute */
 		"%s" 			/* set statement for verbosity */
 		"export opt_to_stdout\n"
 		"opt_to_stdout=\"\"\n"
@@ -1326,6 +1283,43 @@ swverify_write_source_copy_script2(GB * G,
 		"debug_task_shell=\"%s\"\n"
 		"swexec_status=0\n"
 		"export LOCKPATH\n"
+
+		"#\n"
+		"# make targetpath absolute\n"
+		"#\n"
+		"case \"$targetpath\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$targetpath\"\n"
+		"shls_make_dir_absolute\n"
+		"targetpath=\"$mda_target_path\"\n"
+		"# targetpath is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make absolute\n"
+		"#\n"
+
+		"#\n"
+		"# make dirname absolute\n"
+		"#\n"
+		"case \"$dirname\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$dirname\"\n"
+		"shls_make_dir_absolute\n"
+		"dirname=\"$mda_target_path\"\n"
+		"# dirname is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make dirname absolute\n"
+		"#\n"
+
 		"# Here is the override of the shls_looper_payload function\n"
 		"#\n"
 		"%s\n"    /* <<<--- shls_looper_payload */
@@ -1456,6 +1450,7 @@ swverify_write_source_copy_script2(GB * G,
 /*_% */	shlib_get_function_text_by_name("lf_make_lockfile_entry", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("lf_test_lock", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("lf_remove_lock", shell_lib_buf, NULL),
+/*_% */	shlib_get_function_text_by_name("shls_make_dir_absolute", shell_lib_buf, NULL),
 /*_% */		strob_str(set_vx),
 /*_% */		blocksize,
 /*_% */		dirname,
@@ -2092,9 +2087,7 @@ swverify_inl_delete(INFOLINE * inl) {
 
 int
 swverify_inl_parse(INFOLINE * inl, char * line) {
-	char * start;
 	char * s;	
-	char * e;
 	int len;
 
 	/* filename */
