@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,19 +17,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 #ifndef uxformat_19980415_impl_h
 #define uxformat_19980415_impl_h
 
+extern "C" {
+#include "swuser_config.h"
+}
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <limits.h>
 #include <errno.h>
 #include <unistd.h>
 #include <sys/stat.h>
 #include <time.h>
+
 extern "C" {
 #include "xformat.h"
 }
@@ -129,7 +135,7 @@ class uxFormat
 	        xformat_set_gid(xxformatM, gid);
 	}    
   
-	void xFormat_set_filesize (int filesize) { 
+	void xFormat_set_filesize (intmax_t filesize) { 
 	        xformat_set_filesize(xxformatM, filesize);
 	}    
 
@@ -221,42 +227,42 @@ class uxFormat
 		return xformat_clear_pass_buffer(xxformatM);
 	}
 	
-	int xFormat_write_file(void) {
+	intmax_t xFormat_write_file(void) {
 		return xformat_write_file(xxformatM, static_cast<struct stat *>(NULL), 
 			static_cast<char *>(NULL),
 			static_cast<char *>(NULL)
 			);
 	}
 	
-	int xFormat_write_file(char * name, char * source) {
+	intmax_t xFormat_write_file(char * name, char * source) {
 		return xformat_write_file(xxformatM, static_cast<struct stat *>(NULL), name, source);
 	}
 
-	int xFormat_write_file(char * name) {
+	intmax_t xFormat_write_file(char * name) {
 		return xformat_write_file(xxformatM, static_cast<struct stat *>(NULL), name, name);
 	}
 
-	int xFormat_write_file(int source_fd) {
+	intmax_t xFormat_write_file(int source_fd) {
 		return xformat_write_file_by_fd(xxformatM, static_cast<struct stat *>(NULL), (char*)(NULL), (int(*)(int))(NULL), source_fd);
 	}
 
-	int xFormat_write_file(int (*fout)(int)) {
+	intmax_t xFormat_write_file(int (*fout)(int)) {
 		return xformat_write_file_by_fd(xxformatM, static_cast<struct stat *>(NULL), (char*)(NULL), (int(*)(int))(fout), -1);
 	}
 
-	int xFormat_write_file(struct stat * st, char * name) {
+	intmax_t xFormat_write_file(struct stat * st, char * name) {
 	        return xformat_write_file(xxformatM, st, name, NULL);
 	}
 
-	int xFormat_write_file(struct stat *t, char * name , int source_fd) {
+	intmax_t xFormat_write_file(struct stat *t, char * name , int source_fd) {
 		return xformat_write_file_by_fd(xxformatM, t, name, (int(*)(int))(NULL), source_fd);
 	}
 	
-	int xFormat_write_file(struct stat *t, char * name , int (*fout)(int)) {
+	intmax_t xFormat_write_file(struct stat *t, char * name , int (*fout)(int)) {
 		return xformat_write_file_by_fd(xxformatM, t, name, fout, -1);
 	}
 
-	int xFormat_write_file (struct stat *t, char * name, char * source) {
+	intmax_t xFormat_write_file (struct stat *t, char * name, char * source) {
 		return xformat_write_file(xxformatM, t, name, source);
 	}
 	
@@ -268,11 +274,11 @@ class uxFormat
 		return xformat_write_header_wn(xxformatM, name);
 	}
 	
-	int xFormat_read_file_data(int dst_fd) {
+	intmax_t xFormat_read_file_data(int dst_fd) {
 		return xformat_read_file_data(xxformatM, dst_fd);
 	}
 
-	int xFormat_write_file_data(int source_fd) {
+	intmax_t xFormat_write_file_data(int source_fd) {
 		return xformat_write_file_data(xxformatM, source_fd);
 	}
 
@@ -362,15 +368,15 @@ class uxFormat
 		return xformat_read(xxformatM, buf, count);
 	}
 
-	int xFormat_copy_pass(void) {
+	intmax_t xFormat_copy_pass(void) {
 		return xformat_copy_pass_thru(xxformatM);
 	}
 
-	int xFormat_copy_pass (int dst_fd) {
+	intmax_t xFormat_copy_pass (int dst_fd) {
 		return xformat_copy_pass_by_dst(xxformatM, dst_fd);
 	}
 
-	int xFormat_copy_pass (int dst_fd, int src_fd) {
+	intmax_t xFormat_copy_pass (int dst_fd, int src_fd) {
 		return  xformat_copy_pass(xxformatM, dst_fd, src_fd);
 	}
 
