@@ -5,7 +5,7 @@
    COPYING TERMS AND CONDITIONS
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
   
    This program is distributed in the hope that it will be useful,
@@ -15,7 +15,7 @@
   
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef vplob_h_
 #define vplob_h_
@@ -36,5 +36,7 @@ void vplob_add(VPLOB * vplob, void * addr);
 void ** vplob_get_list(VPLOB * vplob);
 void * vplob_val(VPLOB * vplob, int index);
 int vplob_get_nstore(VPLOB * vplob);
+int vplob_delete_store(VPLOB * vplob, void (*f_delete)(void*));
+int vplob_remove_from_list(VPLOB * vplob, void * addr_to_remove);
 
 #endif
