@@ -164,20 +164,28 @@ swheader__reset(SWHEADER * swheader)
 }
 
 static char *
-get_object(SWHEADER * swheader, SWVERID * swverid,
-			int (*f_comp)(SWVERID *, SWVERID *))
+get_object_by_swverid(SWHEADER * swheader, SWVERID * swverid,
+			int (*f_comp)(SWVERID *, SWVERID *), int * nmatches)
 {
+	char * retval;
 	char * next_line;
 	SWVERID *t_swverid = NULL;
+	int start_offset;
 	int object_offset;
+	int ret_object_offset;
 	Swverid_Cmp_Code comparison_result;
 
 
+	retval = NULL;
+	start_offset = swheader_get_current_offset(swheader);
+	ret_object_offset = start_offset;
 	if (f_comp == NULL)
 		f_comp = swverid_vtagOLD_compare;
 
 	SWHEADER_E_DEBUG("");
 
+	if (nmatches) *nmatches = 0;
+
 	/*
 	 * step to first object
  	 */
@@ -192,10 +200,12 @@ get_object(SWHEADER * swheader, SWVERID * swverid,
 	 * Now compare current object to the object described by 'swverid'
 	 */
 	do {
-		object_offset=swheader_get_current_offset(swheader);
+		E_DEBUG("");
+		object_offset = swheader_get_current_offset(swheader);
 		t_swverid = swverid_open(NULL, (char*)(NULL));
 		if (swheader_generate_swverid(swheader, t_swverid, next_line)) {
 			fprintf(stderr, "swheader_get_object: error returned by get_object.\n");	
+			swheader_set_current_offset_p_value(swheader, start_offset);
 			return (char *)NULL;
 		}
 		comparison_result = (*f_comp)(swverid, t_swverid);
@@ -204,15 +214,19 @@ get_object(SWHEADER * swheader, SWVERID * swverid,
 			t_swverid = NULL;
 			swheader_set_current_offset_p_value(swheader,
 								object_offset);
-			return next_line;
+			if (nmatches) (*nmatches)++;
+			retval = next_line;
+			ret_object_offset = object_offset;
+			E_DEBUG("");
 		}
-		swverid_close(t_swverid);
+		if (t_swverid) swverid_close(t_swverid);
 		t_swverid = NULL;
+		E_DEBUG("");
 	} while ((next_line = swheader_get_next_object(swheader,
 					(int)(UCHAR_MAX), (int)UCHAR_MAX)));
 	if (t_swverid) swverid_close(t_swverid);
-	swheader_set_current_offset_p_value(swheader, object_offset);
-	return (char*)NULL;
+	swheader_set_current_offset_p_value(swheader, ret_object_offset);
+	return retval;
 }
 
 void
@@ -224,6 +238,60 @@ restore_state(SWHEADER * header, SWHEADER_STATE * state)
 		*(header->current_offset_p_) = state->save_current_offset_vM;
 }
 
+static
+char *
+get_attribute_in_current_object(SWHEADER * swheader, char *keyword,
+				char * object_keyword, int * is_multi_value)
+{
+	int multi_line;
+	struct swsdflt_defaults *swd;
+	char * line;
+	char * prevline;
+	SWHEADER_STATE state;
+	
+	SWHEADER_E_DEBUG("");
+	swheader_store_state(swheader, &state);
+	if (object_keyword)
+		fprintf(stderr, "warning: get_attribute_in_current_object() is deprecated for this usage\n");
+
+	if (object_keyword) {
+		swd=swsdflt_return_entry(object_keyword, keyword);
+		if (swd == NULL) {
+			multi_line = 
+			(enum swsdflt_value_type)(sdf_single_value);
+		} else {
+			multi_line = swsdflt_get_value_type(swd);
+		}
+	} else {
+		multi_line = (enum swsdflt_value_type)(sdf_single_value);
+	}
+
+	if (multi_line == (enum swsdflt_value_type)(sdf_single_value)) {
+		/*
+		* single value, return the last one.
+		*/
+		if (is_multi_value) *is_multi_value = 0;
+		line = swheader_raw_get_attribute_in_object(swheader, keyword);
+		prevline = line;
+		while (line) {
+			line = swheader_raw_get_attribute_in_object(swheader,
+								keyword);
+			if (line) prevline = line;
+		}
+		restore_state(swheader, &state);
+		return prevline;
+	} else {
+		/*
+		* multi value attribute.
+		*/
+		if (is_multi_value) *is_multi_value = 1;
+		line = swheader_raw_get_attribute_in_object(swheader,
+								keyword);
+		restore_state(swheader, &state);
+		return line;
+	}
+}
+
 
 /* -------------------------------------------------------------------*/
 /* ------------------ Public Functions ------------------------------*/
@@ -601,10 +669,9 @@ swheader_get_single_attribute_value(SWHEADER * swheader, char *keyword)
 {
         char * line;
         char * value;
-	int current_file_offset;
 	SWHEADER_STATE state;
 	swheader_store_state(swheader, &state);
-	line = swheader_get_attribute_in_object(swheader, keyword, NULL, NULL);
+	line = get_attribute_in_current_object(swheader, keyword, NULL, NULL);
 	if (line == NULL) {
 		swheader_restore_state(swheader, &state);
 		return NULL;
@@ -615,15 +682,14 @@ swheader_get_single_attribute_value(SWHEADER * swheader, char *keyword)
 }
 
 char *
-swheader_get_attribute(SWHEADER *swheader, char *attribute_keyword) {
-	int multi;
+swheader_get_attribute(SWHEADER *swheader, char *attribute_keyword, int * is_multi) {
 	char **list;
 	char **pp;
 	char * ret=(char*)(NULL);
 	
 	SWHEADER_E_DEBUG("");
 	list = swheader_get_attribute_list(swheader,
-					attribute_keyword, &multi);
+					attribute_keyword, is_multi);
 	pp = list;
 	if (!list) return (char*)(NULL);
 	/* return the last item in the list. */	
@@ -635,6 +701,15 @@ swheader_get_attribute(SWHEADER *swheader, char *attribute_keyword) {
 	return ret;
 }
 
+char *
+swheader_get_attribute_in_current_object(SWHEADER * swheader, char *keyword,
+				char * object_keyword, int * is_multi_value)
+{
+	return
+		get_attribute_in_current_object(swheader, keyword,
+				object_keyword, is_multi_value);
+}
+
 char **
 swheader_get_attribute_list(SWHEADER *swheader,
 			char *attribute_keyword, int *multi_line)
@@ -738,24 +813,38 @@ swheader_get_object_by_tag(SWHEADER * swheader,
 					char *object_keyword,
 						char *idtag)
 {
-	SWVERID *swverid = swverid_open(object_keyword, (char*)(NULL));
+	SWVERID *swverid;
 	char *ret;
 
-	SWHEADER_E_DEBUG("");
-	swverid_set_tag(swverid, "tag", idtag);
+	E_DEBUG("");
+	swverid = swverid_open(object_keyword, (char*)(NULL));
+	E_DEBUG("");
+	swverid_set_tag(swverid, SW_A_tag, idtag);
+	E_DEBUG("");
 	swverid_set_comparison_code(swverid, SWVERID_CMP_EQ);
-	ret = get_object(swheader, swverid, swverid_vtagOLD_compare);
+	E_DEBUG("");
+	ret = get_object_by_swverid(swheader, swverid, swverid_vtagOLD_compare, (int*)NULL);
+	E_DEBUG("");
 	swverid_close(swverid);
 	return ret;
 }
 
+
+char *
+swverid_get_object_by_swverid(SWHEADER * swheader, SWVERID * swverid,  int * nmatches)
+{
+	char * ret;
+	ret = get_object_by_swverid(swheader, swverid, swverid_vtagOLD_compare, nmatches);
+	return ret;
+}
+
+
 int
 swheader_get_object_offset_by_control_directory(SWHEADER * swheader,  STRAR * pairs)
 {
 	char * next_line;
 	int object_offset = 0;  /* FIXME */
 	char * control_directory;
-	char * tag;
 
 	/*
 	 * first handle a minimal package.
@@ -763,8 +852,6 @@ swheader_get_object_offset_by_control_directory(SWHEADER * swheader,  STRAR * pa
 	 * product and one fileset.
 	 */	
 
-
-
 	SWHEADER_E_DEBUG("");
 	/* step to first object */
 	
@@ -815,56 +902,6 @@ swheader_raw_get_attribute_in_object(SWHEADER * swheader, char *keyword)
 }
 
 
-char *
-swheader_get_attribute_in_object(SWHEADER * swheader, char *keyword,
-				char * object_keyword, int * is_multi_value)
-{
-	int multi_line;
-	struct swsdflt_defaults *swd;
-	char * line;
-	char * prevline;
-	SWHEADER_STATE state;
-	
-	SWHEADER_E_DEBUG("");
-	swheader_store_state(swheader, &state);
-	if (object_keyword) {
-		swd=swsdflt_return_entry(object_keyword, keyword);
-		if (swd == NULL) {
-			multi_line = 
-			(enum swsdflt_value_type)(sdf_single_value);
-		} else {
-			multi_line = swsdflt_get_value_type(swd);
-		}
-	} else {
-		multi_line = (enum swsdflt_value_type)(sdf_single_value);
-	}
-
-	if (multi_line == (enum swsdflt_value_type)(sdf_single_value)) {
-		/*
-		* single value, return the last one.
-		*/
-		if (is_multi_value) *is_multi_value = 0;
-		line = swheader_raw_get_attribute_in_object(swheader, keyword);
-		prevline = line;
-		while (line) {
-			line = swheader_raw_get_attribute_in_object(swheader,
-								keyword);
-			if (line) prevline = line;
-		}
-		restore_state(swheader, &state);
-		return prevline;
-	} else {
-		/*
-		* multi value attribute.
-		*/
-		if (is_multi_value) *is_multi_value = 1;
-		line = swheader_raw_get_attribute_in_object(swheader,
-								keyword);
-		restore_state(swheader, &state);
-		return line;
-	}
-}
-
 int
 swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file_hdr)
 {
@@ -883,7 +920,6 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 	char did_gid = 0;
 	char did_uid = 0;
 	char did_mtime = 0;
-	char did_mode = 0;
 	char did_link_source = 0;
 	char did_size = 0;
 	char did_major = 0;
