@@ -297,6 +297,13 @@ write_query_blob(GB * G, SWVERID * swverid, STROB * buf, STROB * tmp, int query_
 	struct VER_ID * verid;
 
 	strob_sprintf(buf, 1, "SW_SOC_SPEC=\"%s\"\n", swverid->source_copyM);
+
+	strob_sprintf(buf, 1, 
+			"SWBIS_UTIL_NAME=\"%s\"\n"
+			"SWBIS_CL_TARGET_TARGET=\"%s\"\n",
+			swlib_utilname_get(),
+			(G->g_cl_target_targetM != NULL ? G->g_cl_target_targetM: "(unset)")
+			);
 	
 	/* set the defaults to include everything */
 	strob_sprintf(buf, 1, "SWBIS_SOC_SPEC1=\".*\"\n");
@@ -418,26 +425,6 @@ write_shell_assign1(STROB * buf, char * varname, char * value)
 	strob_sprintf(buf, STROB_DO_APPEND, "%s=\"${%s:=\"%s\"}\"\n", varname, varname, value);
 }
 
-static
-void
-write_attributes(STROB * buf, SWHEADER * swheader, int index)
-{
-	char * line;
-	int level;
-	char * keyword;
-	char * value;
-
-	swheader_store_state(swheader, NULL);
-	swheader_set_current_offset(swheader, index);
-	while((line=swheader_get_next_attribute(swheader))) {
-		keyword = swheaderline_get_keyword(line);
-		value = swheaderline_get_value(line, (int *)NULL);
-		level = swheaderline_get_level(line);
-		swdef_write_keyword_to_buffer(buf, keyword, level, SWPARSE_MD_TYPE_ATT);
-		swdef_write_value_to_buffer(buf, value);
-	}
-	swheader_restore_state(swheader, NULL);
-}
 
 static
 void
@@ -572,6 +559,46 @@ squash_null_block(char * start, int len)
 	return nn;
 }
 
+static
+void
+write_attributes(STROB * buf, SWHEADER * swheader, int index)
+{
+	char * line;
+	int level;
+	char * keyword;
+	char * value;
+
+	swheader_store_state(swheader, NULL);
+	swheader_set_current_offset(swheader, index);
+	while((line=swheader_get_next_attribute(swheader))) {
+		keyword = swheaderline_get_keyword(line);
+		value = swheaderline_get_value(line, (int *)NULL);
+		level = swheaderline_get_level(line);
+		swdef_write_keyword_to_buffer(buf, keyword, level, SWPARSE_MD_TYPE_ATT);
+		swdef_write_value_to_buffer(buf, value);
+	}
+	swheader_restore_state(swheader, NULL);
+}
+
+void
+write_isf_excludes(STROB * ibuf, SWI * swi)
+{
+	int fd;
+	int n;
+	char * s;
+	STROB * buf;
+	fd = swi->pending_file_conflicts_fdM;
+	if (fd < 0) return;
+	buf = strob_open(32);
+	uxfio_lseek(fd, 0, SEEK_SET);
+	while ((n=swgp_read_line(fd, (STROB*)buf, DO_NOT_APPEND)) > 0) {
+		s = strob_str(buf);
+		while(swlib_squash_trailing_char(s, '\n') == 0);
+		strob_sprintf(ibuf, 0, SW_A_excluded_from_install " " "\"%s\"\n", s);
+	}
+	strob_close(buf);
+}
+
 int
 swicat_write_installed_software(SWI * swi, int ofd)
 {
@@ -645,11 +672,12 @@ int
 swicat_isf_fileset(SWI * swi, STROB * buf, SWI_XFILE * xfile, int do_if_active)
 {
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_fileset "\n");
-	strob_sprintf(buf, STROB_DO_APPEND, "    " SW_A_location " %s\n", swi->swi_pkgM->locationM);
+	strob_sprintf(buf, STROB_DO_APPEND, "    " SW_A_location " %s\n", swi->swi_pkgM->locationM ? swi->swi_pkgM->locationM:"/");
 	write_attributes(buf, SWI_INDEX_HEADER(swi), xfile->baseM.header_indexM);
 	write_state(buf, xfile, do_if_active);
 	write_times(buf, (SWI_BASE *)&(xfile->baseM), 1 /* do_if_active */);
 	swicat_isf_all_scripts(buf, xfile->swi_scM, do_if_active);
+	write_isf_excludes(buf, swi);
 	strob_sprintf(buf, STROB_DO_APPEND, "\n");
 	return 0;
 }
@@ -663,7 +691,7 @@ swicat_isf_product(SWI * swi, STROB * buf, SWI_PRODUCT * prod, int do_if_active)
 	swheader = SWI_INDEX_HEADER(swi);
 	/* if (do_if_active && !(prod->is_activeM)) return 0; */
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_product "\n");
-	strob_sprintf(buf, STROB_DO_APPEND, SW_A_location " %s\n", swi->swi_pkgM->locationM);
+	strob_sprintf(buf, STROB_DO_APPEND, SW_A_location " %s\n", swi->swi_pkgM->locationM ? swi->swi_pkgM->locationM:"/");
 		
 	write_attributes(buf, SWI_INDEX_HEADER(swi), prod->p_baseM.header_indexM);
 
@@ -970,7 +998,6 @@ swicat_write_isc_script(STROB * script_buf,
 		VPLOB * swspecs_pre,
 		VPLOB * swspecs_co,
 		VPLOB * swspecs_ex,
-		char * target_path,
 		char * list_vform)
 {
 	int query_num;
@@ -979,11 +1006,14 @@ swicat_write_isc_script(STROB * script_buf,
 	STROB * tmp;
 	STROB * shell_lib_buf;
 	char * list_lform;
+	char * isc_path;
 
 	tmp = strob_open(1);
 	shell_lib_buf = strob_open(1);
 	strob_strcpy(script_buf, "");
 
+	isc_path = get_opta_isc(G->optaM, SW_E_installed_software_catalog);
+
 	if (strcmp(list_vform, SWICAT_FORM_TAR1) == 0) {
 		/* Create a tar archive of the selections */
 
@@ -1013,6 +1043,8 @@ swicat_write_isc_script(STROB * script_buf,
 		"export SWBIS_QUERY_NUM\n"
 		"export SWBIS_LIST_FORM\n"
 		"export SWBIS_REQ_TYPE\n"
+		"export SWBIS_UTIL_NAME\n"
+		"export SWBIS_CL_TARGET_TARGET\n"
 		"%s\n"
 		"%s\n"
 		"%s\n",
@@ -1020,7 +1052,7 @@ swicat_write_isc_script(STROB * script_buf,
 		shlib_get_function_text_by_name("shls_apply_socspec", tmp, NULL),
 		shlib_get_function_text_by_name("shls_get_verid_list", tmp, NULL)
 		);
-
+			
 	/* put shell functions here needed for writing the tar format here */
 	if (strcmp(list_vform, SWICAT_FORM_TAR1) == 0) {
 		strob_sprintf(script_buf, 1,
@@ -1029,12 +1061,11 @@ swicat_write_isc_script(STROB * script_buf,
 			"%s\n"
 			"%s\n"
 			"%s\n"
-			"%s\n",
+			,
 			shlib_get_function_text_by_name("shls_false_", shell_lib_buf, NULL),
 			shlib_get_function_text_by_name("shls_check_for_gnu_tar", shell_lib_buf, NULL),
 			shlib_get_function_text_by_name("shls_missing_which", shell_lib_buf, NULL),
-			shlib_get_function_text_by_name("shls_write_cat_ar", shell_lib_buf, NULL),
-			""
+			shlib_get_function_text_by_name("shls_write_cat_ar", shell_lib_buf, NULL)
 			);
 	}
 
@@ -1045,6 +1076,16 @@ swicat_write_isc_script(STROB * script_buf,
 
 	/* Beginning subshell */
 
+	if (isc_path)
+		strob_sprintf(script_buf, 1, "cd \"%s\"\n", isc_path);
+	else
+		strob_sprintf(script_buf, 1, "(exit 1);\n");
+
+	strob_sprintf(script_buf, 1, 
+	"case $? in\n"
+	"	0)\n"
+	);
+
 	strob_sprintf(script_buf, 1, 
 			"sw_retval=0\n"
 			"(\n"		/* subshell */
@@ -1122,15 +1163,18 @@ swicat_write_isc_script(STROB * script_buf,
 			")\n"
 			") | shls_write_cat_ar\n");
 	} else {
-		strob_sprintf(script_buf, 1,
-			"printf \"" CPIO_INBAND_EOA_FILENAME "\\r\\n\"\n"
-			"printf \"\\r\\n\"\n"
-			") | dd 2>/dev/null\n"
-			") | dd obs=%d 2>/dev/null | dd ibs=%d obs=%d conv=sync 2>/dev/null 2>/dev/null\n",
-			SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*2, SWLIB_SYNCT_BLOCKSIZE*2);
-			/* Ending Subshell with sync'ing dd */
+		swlib_append_synct_eof(script_buf);
 	}
 
+	strob_sprintf(script_buf, 1, 
+	";;\n"
+	"	*)\n"
+	"	echo \"internal error: bad installed_software_catalog path in swicat_write_isc_script\"\n"
+	"	sw_retval=1\n"
+	"	;;\n"
+	"esac\n"
+	);
+
 	strob_close(tmp);
 	strob_close(shell_lib_buf);
 	return 0;
@@ -1323,6 +1367,7 @@ swicat_req_delete(SWICAT_REQ * req)
 	free(req);
 }
 
+
 #ifdef VMAIN
 #include "swmain.h"
 int
