@@ -181,6 +181,68 @@ init_catalog_entry(SWICAT_E * e, SWVARFS * swvarfs, char * fpath)
 	E_DEBUG("LEAVING");
 	return 0;
 }
+	
+static
+int
+initialize_file_conflicts_fd(SWI * swi, SWHEADER * swheader)
+{
+	char * line;
+	char * next_line;
+	char * tag;
+	char * number;
+	char * value;
+	char * keyword;
+	int retval;
+	int ix;
+	int ex_memfd;
+	int re_memfd;
+	SWHEADER_STATE state1;
+
+	E_DEBUG("");
+	ex_memfd = -1;
+	re_memfd = -1;
+	retval = 0;
+	swheader_store_state(swheader, &state1);
+	swheader_reset(swheader);
+	
+	/* Loop over the objects in the SW_A_INSTALLED file */
+
+	E_DEBUG("");
+	while ((next_line=swheader_get_next_object(swheader, (int)UCHAR_MAX, (int)UCHAR_MAX))) {
+		E_DEBUG2("next_line=%s\n", next_line);
+		if (swheaderline_get_type(next_line) != SWPARSE_MD_TYPE_OBJ) {
+			/* Sanity check */
+			return -1;
+			SWBIS_IMPL_ERROR_DIE(1);
+		}
+		keyword = swheaderline_get_keyword(next_line);
+
+		if (strcmp(keyword, SW_A_product) == 0) {
+			;
+		} else if (strcmp(keyword, SW_A_fileset) == 0) {
+			while((line=swheader_get_next_attribute(swheader))) {
+				keyword = swheaderline_get_keyword(line);
+				value = swheaderline_get_value(line, (int *)NULL);
+				if (strcmp(keyword, SW_A_excluded_from_install) == 0) {
+					if (ex_memfd < 0) ex_memfd = swlib_open_memfd();
+					uxfio_write(ex_memfd, value, strlen(value));
+					uxfio_write(ex_memfd, "\n", 1);
+				} else if (strcmp(keyword, SW_A_replaced_by_install) == 0) {
+					if (re_memfd < 0) re_memfd = swlib_open_memfd();
+					uxfio_write(re_memfd, value, strlen(value));
+					uxfio_write(re_memfd, "\n", 1);
+				}
+			}
+			if (ex_memfd > 0) uxfio_write(ex_memfd, "\0", 1);
+			if (re_memfd > 0) uxfio_write(re_memfd, "\0", 1);
+			break;
+		}
+	}
+	swheader_restore_state(swheader, &state1);
+	swi->excluded_file_conflicts_fdM = ex_memfd;
+	swi->replaced_file_conflicts_fdM = re_memfd;
+	return 0;
+}
 
 SWICAT_E *
 swicat_e_create(void)
@@ -664,6 +726,7 @@ swicat_e_open_swi(SWICAT_E * e)
 {
 	SWI * swi;
 	int ret;
+	int isf_status;
 	int ifd;
 	int newfd;
 	int newfd2;
@@ -674,6 +737,7 @@ swicat_e_open_swi(SWICAT_E * e)
         SWVARFS * swvarfs;
 	SWPATH * swpath;
 	UINFORMAT * uinformat;
+	SWHEADER * installed_header;
 
 	E_DEBUG("BEGIN");
 	E_DEBUG2("LOWEST ENTERING AA swicat_e_open_swi FD=%d", show_nopen());
@@ -842,6 +906,10 @@ swicat_e_open_swi(SWICAT_E * e)
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 	E_DEBUG2("swi=%p", (void*)swi);
 	E_DEBUG2("LOWEST LEAVING AA swicat_e_open_swi FD=%d", show_nopen());
+
+	installed_header = swicat_e_isf_parse(e, &isf_status, (AHS*)NULL);
+	initialize_file_conflicts_fd(swi, installed_header);
+
 	return swi;
 }
 
