@@ -338,11 +338,10 @@ set_selected_index(SWICOL * swicol, int first_current_event)
 	
 static
 void
-set_buf(char ** p_dst, char * buf)
+set_buf(char ** dst, char * buf)
 {
-	char * dst = *p_dst;
-	if (dst) free(dst);
-	dst = strdup(buf);	
+	if (*dst) free(*dst);
+	*dst = strdup(buf);	
 }
 
 static
@@ -387,10 +386,12 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 	char * ablocks;
 	STROB * enddesc;
 	STROB * ubuf;
+	STROB * synct_eof_buf;
 	uintmax_t blocks;
 	
 	ubuf = strob_open(32);
 	enddesc = strob_open(32);
+	synct_eof_buf = strob_open(32);
 	blocks = (int)(size / 512);
 	if (size % 512) {
 		/*
@@ -405,6 +406,7 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 	 */
 
 	if (swlib_is_ascii_noaccept(dir, SWBIS_TAINTED_CHARS "\a\b\n\r\t \v\\", 1)) {
+		fprintf(stderr, "print_task_script: illegal dir: %s\n", dir);
 		return 1;
 	}
 
@@ -420,6 +422,14 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		tonullstring = "2>/dev/null";
 	}
 
+	if (swicol->needs_synct_eoaM) {
+		strob_sprintf(synct_eof_buf, 0,
+		"(\n"
+		"(\n"
+		);
+		swlib_append_synct_eof(synct_eof_buf);
+	}
+
 	strob_sprintf(enddesc, 0, "%s: " SWEVENT_STATUS_PFX "$sw_retval", task_desc);
 
 	ablocks = swlib_umaxtostr(blocks, ubuf);
@@ -438,7 +448,8 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		"		0)\n"
 		" 			;;\n"
 		"		*)\n"
-		"			dd count=%d of=/dev/null 2>/dev/null\n"
+		"			dd count=%s of=/dev/null 2>/dev/null\n"
+		"			%s\n"	
 		"			%s\n"
 		"			exit \"$swret\"\n"
 		"			;;\n"
@@ -461,6 +472,7 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		dir,
 		verbosestring,
 		ablocks,
+		strob_str(synct_eof_buf),
 		TEVENT(2, -1, SW_INTERNAL_ERROR, "No such directory or no access: $swxdir"),
 		task_script,
 		swlib_utilname_get(),
@@ -468,6 +480,7 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		TEVENT(2, -1, SWI_TASK_ENDS, strob_str(enddesc))
 		);
 
+	strob_close(synct_eof_buf);
 	strob_close(ubuf);
 	strob_close(enddesc);
 	return 0;
@@ -493,6 +506,7 @@ swicol_create(void)
 	swicol->event_indexM = 1;
 	swicol->id_stringM = strob_open(24);
 	swicol->debug_task_scriptsM = 0;
+	swicol->needs_synct_eoaM = 0;
 	init_magic_header(swicol);
 	swicol_clear_master_alarm(swicol);
 	swicol_set_event_fd(swicol, -1);
@@ -585,6 +599,7 @@ swicol_rpsh_task_send_script2(SWICOL * swicol, int fd,
 	desc = f_desc;	
 	if (swicol_get_master_alarm_status(swicol) == SWICOL_ABORT_STEP_2) {
 		return -1;
+		return 0;
 	} else if (swicol_get_master_alarm_status(swicol) == SWICOL_ABORT_STEP_1) {
 		/* do the task script but intensionally send a wrong task
 		   id_string, this will cause the target main script to abort */
@@ -646,7 +661,7 @@ swicol_rpsh_task_send_script(SWICOL * swicol, int fd,
 	}
 
 	if (print_task_script(swicol, tmp, data_size, dir, script, desc)) {
-		fprintf(stderr, "rpsh_task_send_script: error forming task script\n");
+		fprintf(stderr, "swicol_rpsh_task_send_script: error forming task script\n");
 		return -2;
 	}
 	
