@@ -74,7 +74,6 @@ static
 ssize_t
 synct_i_read(SYNCT * synct, int fd, char * buf)
 {
-	char * p;
 	ssize_t ret;
 	E_DEBUG("");
 	ret = uxfio_sfa_read(fd, buf, SWLIB_SYNCT_BLOCKSIZE);
@@ -92,7 +91,6 @@ static
 char * 
 synct_look_for_eof(SYNCT * synct, unsigned char ** p_trailer_start)
 {
-	static int d;
 	unsigned char * ibuf;
 	unsigned char * pos;
 	int len;
@@ -330,7 +328,6 @@ swlib_i_digs_copy(int ofd, int ifd, intmax_t count, FILE_DIGS * digs, int adjunc
 	unsigned char res_sha512[65];  /* binary result */
 	unsigned char sha1ctx[512];
 	unsigned char sha512ctx[512];
-	uintmax_t sz;
 	int sleepbytes = 0;
 	int timebytes = 0;
 	time_t newt;
@@ -2340,6 +2337,12 @@ swlib_open_memfd(void)
 	return fd;
 }
 
+int
+swlib_close_memfd(int fd)
+{
+	return uxfio_close(fd);
+}
+
 int
 swlib_pad_amount(int fd, int amount)
 {
@@ -2380,10 +2383,10 @@ swlib_drop_root_privilege(void)
 		 * Only attempt to drop root privilidge if
 		 * you are root
 		 */
-		if (taru_get_uid_by_name("nobody", &nob) < 0) {
+		if (taru_get_uid_by_name(AHS_USERNAME_NOBODY, &nob) < 0) {
 			fprintf(stderr, 
-	     "%s: Warning: the uname [nobody] not found, not dropping privilege.\n",
-			swlib_utilname_get());
+	     "%s: Warning: the uname [%s] not found, not dropping privilege.\n",
+			swlib_utilname_get(), AHS_USERNAME_NOBODY);
 			ret = 3;
 		} else {
 			if (nob < 10) {
@@ -2767,3 +2770,16 @@ swlib_squash_illegal_tag_chars(char * s)
 		s++;
 	}
 }
+
+void
+swlib_append_synct_eof(STROB * buf)
+{
+	/* Here is the SWBIS_SYNCT_EOF */
+	strob_sprintf(buf, 1, /* append */
+		"printf \"" CPIO_INBAND_EOA_FILENAME "\\r\\n\"\n"
+		"printf \"\\r\\n\"\n"
+		") | dd 2>/dev/null\n"
+		") | dd obs=%d 2>/dev/null | dd ibs=%d obs=%d conv=sync 2>/dev/null\n",
+		SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*2, SWLIB_SYNCT_BLOCKSIZE*2);
+		/* Ending Subshell with sync'ing dd */
+}
