@@ -13,6 +13,7 @@
 #include "xformat.h"
 #include "taru.h"
 #include "swlib.h"
+#include "etar.h"
 #include "swparser_global.h"
 #include "swevents_array.h"
 #include "swcommon_options.h"
@@ -411,6 +412,7 @@ main (int argc, char ** argv ) {
                {"group", 1, 0, 156},
                {"oldgnu-namesize", 0, 0, 157},
                {"gnu-namesize", 0, 0, 158},
+               {"scratch-pad", 1, 0, 159},
                {"help", 0, 0, '\005'},
                {0, 0, 0, 0}
              };
@@ -472,6 +474,19 @@ main (int argc, char ** argv ) {
 	       case 158:
 			xformat_set_tarheader_flag(xformat, TARU_TAR_NAMESIZE_99, 0);
 			break;
+	       case 159:
+			{
+				#define ETAR__HDR(a)  ((struct tar_header *)((a)->tar_hdrM))
+				unsigned long devno;
+				TARU * taru = taru_create();
+				ETAR * etar;
+				etar = etar_open(taru);
+				devno = swlib_atoul(optarg, (int *)NULL);	
+				etar_set_devmajor(etar, devno);
+				fprintf(stdout, "%s\n", (char*)(ETAR__HDR(etar)->devmajor));
+			}
+			exit(0);
+			break;
                default:
 			exit(1);
 			break;
