@@ -109,7 +109,15 @@ lf_remove_lock() {
 	case "$?" in
 		0)
 			lfCCname=$(lf_make_lockfile_name)
+			test -f "$lfCCname"
+			case "$?" in
+			0)
 			/bin/rm -f "$lfCCname"
+			;;
+			*)
+			(exit 1);
+			;;
+			esac
 		;;
 	esac
 	return $?
@@ -253,6 +261,8 @@ shls_apply_socspec() {
 		ep_line_tag=ENVIRON["SWBIS_QUERY_NUM"];
 		ep_list_form=ENVIRON["SWBIS_LIST_FORM"];
 		ep_req_type=ENVIRON["SWBIS_REQ_TYPE"];
+		ep_cl_target_target=ENVIRON["SWBIS_CL_TARGET_TARGET"];
+		ep_swbis_util_name=ENVIRON["SWBIS_UTIL_NAME"];
 
 		bundle_match_indicator="."
 		product_match_indicator="."
@@ -489,6 +499,9 @@ shls_apply_socspec() {
 	}
 	END {
 		if (number_of_matches == 0) {
+			if (ep_list_form == "lform_p1") {
+				print ep_swbis_util_name ": SW_SELECTION_NOT_FOUND on " ep_cl_target_target ": " ep_soc_spec | "cat 1>&2"
+			}
 			if (ep_list_form == "lform_dep1") {
 				print response_prefix "...:"
 			}
@@ -587,7 +600,7 @@ shls_bashin2() {
 	case ${#result} in
 		0) ;;
 		*)
-			echo "$swutilname: error: shls_bashin taskId mismatch: $A2: $T2" 1>&2 0</dev/null
+			echo "$swutilname: error: shls_bashin taskId mismatch at $A2: received $T2" 1>&2 0</dev/null
 			swexec_status=1
 			;;
 	esac
@@ -2155,3 +2168,20 @@ shls_cleansh() {
 	shls__cleansh </dev/null
 	return $?
 }
+
+shls_make_dir_absolute() {
+	case "$mda_target_path" in
+		/*)
+			;;
+		*)
+		case "$mda_pwd" in
+			/)
+			mda_target_path=/"$mda_target_path"
+			;;
+			*)
+			mda_target_path="$mda_pwd"/"$mda_target_path"
+			;;
+		esac
+		;;
+	esac
+}
