@@ -220,23 +220,29 @@ swi_get_distribution_attributes(SWI * swi, SWHEADER * swheader)
 	char * value;
 	char * obj;
 	
+	E_DEBUG("");
 	swi_com_header_manifold_reset(swheader);
+	E_DEBUG("");
 	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "*" );
+	E_DEBUG("");
 	if (!obj) {
 		return -1;
 	}
+	E_DEBUG("");
 	value = swheader_get_single_attribute_value(swheader, SW_A_dfiles);
 	if (value)
 		swi->swi_pkgM->dfiles_attributeM = strdup(value);
 	else
 		swi->swi_pkgM->dfiles_attributeM = strdup(SW_A_dfiles);
 
+	E_DEBUG("");
 	value = swheader_get_single_attribute_value(swheader, SW_A_pfiles);
 	if (value)
 		swi->swi_pkgM->pfiles_attributeM = strdup(value);
 	else
 		swi->swi_pkgM->pfiles_attributeM = strdup(SW_A_pfiles);
 
+	E_DEBUG("");
 	return 0;
 }
 
@@ -335,6 +341,11 @@ swi_delete(SWI * s)
 		uinfile_close(s->uinformatM);
 	}
 	E_DEBUG2("LEAVING swi_delete: LOWEST FD=%d", show_nopen());
+
+	uxfio_close(s->excluded_file_conflicts_fdM);
+	uxfio_close(s->replaced_file_conflicts_fdM);
+	uxfio_close(s->pending_file_conflicts_fdM);
+
 	free(s);
 }
 
@@ -363,6 +374,10 @@ SWI * swi_create(void)
 	swi->xformat_close_on_deleteM = 0;
 	swi->swvarfs_close_on_deleteM = 0;
 	swi->uinformat_close_on_deleteM = 0;
+
+	swi->excluded_file_conflicts_fdM = -1;
+	swi->replaced_file_conflicts_fdM = -1;
+	swi->pending_file_conflicts_fdM = -1;
 	return swi;
 }
 
@@ -477,10 +492,10 @@ swi_expand_shared_file_control_sripts(SWI * swi, SWI_XFILE * xfile)
 			swheader_get_current_offset_p(swheader), 
 				SWHEADER_PEEK_NEXT);
 		path_attr = swheader_get_attribute(swheader,
-			SW_A_path);
+			SW_A_path, NULL);
 		SWLIB_ASSERT(path_attr != NULL);
 		tag_attr = swheader_get_attribute(swheader,
-			SW_A_tag);
+			SW_A_tag, NULL);
 		SWLIB_ASSERT(tag_attr != NULL);
 
 		/*
@@ -601,26 +616,32 @@ swi_parse_file(
 				SWHEADER_GET_NEXT);
 			break;
 		case SWPARSE_SWDEF_FILETYPE_INDEX:
-			E_DEBUG("case");
+			E_DEBUG("SWPARSE_SWDEF_FILETYPE_INDEX");
 			swi->swi_pkgM->baseM.global_headerM = swheader;
 			swi->swi_pkgM->baseM.header_indexM = 0;
 			swi->swi_pkgM->swdef_fdM = curfd;
 			swi->swi_pkgM->did_parse_def_fileM = 1;
 			
+			E_DEBUG("");
 			swheader_set_current_offset_p(swheader, 
 					&(swi->swi_pkgM->baseM.header_indexM));
 			swheader_set_current_offset_p_value(swheader, 0);
 			swheader_reset(swheader);
+			E_DEBUG("");
 			swheader_goto_next_line(swheader,
 				swheader_get_current_offset_p(swheader),
 				SWHEADER_GET_NEXT);
 			
+			E_DEBUG("");
 			if (swi_get_distribution_attributes(swi, swheader) != 0)
 				swi_com_fatal_error( __FILE__, __LINE__);
+			E_DEBUG("");
 			swpath_set_dfiles(swpath, 
 					swi->swi_pkgM->dfiles_attributeM);
+			E_DEBUG("");
 			swpath_set_pfiles(swpath, 
 					swi->swi_pkgM->pfiles_attributeM);
+			E_DEBUG("");
 			break;
 		default:
 			swi_com_fatal_error( __FILE__ ":invalid case", __LINE__);
@@ -992,7 +1013,19 @@ swi_decode_catalog(SWI * swi)
 
 	/* Now fix-up the control scripts that share
 	   a common control file.  */
+	E_DEBUG("");
+
+	if (
+		swi->swi_pkgM == NULL
+		/*
+		swi->swi_pkgM->swi_coM[0] == NULL ||
+		swi->swi_pkgM->swi_coM[0]->xfileM == NULL
+		*/
+	) {
+		return -8;
+	}
 	ret = swi_expand_shared_file_control_sripts(swi, swi->swi_pkgM->swi_coM[0]->xfileM);
+	E_DEBUG("");
 	swi_com_assert_value(ret == 0, __FILE__, __LINE__);
 
 	E_DEBUG("");
@@ -1496,23 +1529,10 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 	int n_compat;
 	int check_found;
 	int product_number;
-	int ret;
-	char * object_line;
-	char * object_keyword;
-	char * directory;
-	char * path;
-	char * prefix;
-	char * store;
-	char * filetype;
-	char * is_volatile;
-	int tar_filetype;
 	int n_products;
 	STROB * relocated_path;
 	SWI_FILELIST * flist;
 	SWI_PRODUCT * product;
-	SWHEADER * infoheader;
-	SWHEADER * global_index;
-	SWHEADER_STATE state;
 
 	E_DEBUG("");
 	flist = swi_fl_create();
@@ -1671,7 +1691,6 @@ int
 swi_fl_is_volatile(SWI_FILELIST * fl, int index) {
 	STRAR * ar = (STRAR*)fl;
 	char * s;
-	int ret;
 	s = strar_get(ar, index);
 	if (s == NULL) return 0;
 	if ((int)(*(s + SWI_FL_OFFSET_IS_VOLATILE)) == 'T') {
