@@ -53,6 +53,7 @@
 #define SWI_FL_OFFSET_TARTYPE		0
 #define SWI_FL_OFFSET_IS_VOLATILE	1
 #define SWI_FL_OFFSET_USER_FLAG		2
+#define SWI_FL_OFFSET_KEEP_FLAG		3
 #define SWI_FL_OFFSET_PATH		10
 #define SWI_FL_HEADER_LEN		10
 
@@ -151,6 +152,10 @@ typedef struct {	/* The Global package control structure */
 	int opt_alt_catalog_rootM; /* -r option				*/
 	char * exported_catalog_prefixM; /* i.e.  <path>/catalog/ from  */
 				/* the distribution 			*/
+	int excluded_file_conflicts_fdM; /* List of SW_A_excluded_from_install */
+	int replaced_file_conflicts_fdM; /* List of SW_A_replaced_by_install  */
+	int pending_file_conflicts_fdM; /* */
+
 	SWICOL * swicolM;
 	STRAR * swevent_listM;
 	void * optaM;		/* extended options structure		*/
