@@ -55,7 +55,7 @@ loop_and_record(SWHEADER * INDEX, char * object_keyword, STRAR * list,
 
 	obj = swheader_get_object_by_tag(INDEX, object_keyword, "*");
 	while(obj) {
-		attrline = swheader_get_attribute(INDEX, SW_A_tag);
+		attrline = swheader_get_attribute(INDEX, SW_A_tag, NULL);
 		if (!attrline) {
 			fprintf(stderr, "no tag found for %s\n", object_keyword);
 			retval = 20;
@@ -64,13 +64,13 @@ loop_and_record(SWHEADER * INDEX, char * object_keyword, STRAR * list,
 		value = swheaderline_get_value(attrline, NULL);
 		strar_add(list, value);
 
-		attrline = swheader_get_attribute(INDEX, SW_A_vendor_tag);
+		attrline = swheader_get_attribute(INDEX, SW_A_vendor_tag, NULL);
 		if (attrline) {
 			value = swheaderline_get_value(attrline, NULL);
 			if (vendor_list) strar_add(vendor_list, value);
 		}
 	
-		attrline = swheader_get_attribute(INDEX, SW_A_revision);
+		attrline = swheader_get_attribute(INDEX, SW_A_revision, NULL);
 		if (!attrline) {
 			/* fprintf(stderr, "no revision found for %s\n", object_keyword); */
 			retval = 23;
@@ -191,7 +191,7 @@ swi_distdata_resolve(SWI * swi, SWI_DISTDATA * part1,
 	}
 	offset = swheader_get_current_offset(INDEX);
 
-	attrline = swheader_get_attribute(INDEX, SW_A_tag);
+	attrline = swheader_get_attribute(INDEX, SW_A_tag, NULL);
 	if (!attrline) { 
 		/*
 		 * dist.tag is optional
