@@ -46,7 +46,7 @@ TARU * taru_create(void)
 	taru->do_record_headerM = 0;	
 	taru->u_name_bufferM = strob_open(8);
 	taru->u_ent_bufferM = strob_open(64);
-	taru->nullfdM = swlib_open_nullfd();
+	taru->nullfdM = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	/* taru->do_md5M = 0; */
 	taru->md5bufM = strob_open(64);
 	strob_set_memlength(taru->md5bufM, 64);
@@ -65,7 +65,7 @@ taru_delete(TARU * taru)
 	strob_close(taru->u_ent_bufferM);
 	strob_close(taru->md5bufM);
 	strob_close(taru->preview_bufferM);
-	swlib_close_nullfd(taru->nullfdM);
+	swbis_devnull_close(taru->nullfdM);
 	free(taru);
 }
 
@@ -136,6 +136,11 @@ taru_digs_print(FILE_DIGS * digs, STROB * buffer)
 		strob_sprintf(buffer, STROB_DO_APPEND, " []");
 }
 
+void
+taru_digs_delete(FILE_DIGS * digs)
+{
+	free(digs);
+}
 
 FILE_DIGS *
 taru_digs_create(void)
@@ -175,7 +180,7 @@ void
 taru_free_header_digs(struct new_cpio_header * file_hdr)
 {
 	if (file_hdr->digsM) {
-		free(file_hdr->digsM);
+		taru_digs_delete(file_hdr->digsM);
 		file_hdr->digsM = NULL;
 	}
 }
@@ -201,7 +206,7 @@ taru_init_header(struct new_cpio_header * file_hdr)
 	ahsStaticSetTarLinkname(file_hdr, "");
 	ahsStaticSetTarFilename(file_hdr, "");
 	file_hdr->usage_maskM = 0;
-	file_hdr->digsM = NULL;
+	taru_init_header_digs(file_hdr);
 }
 
 struct new_cpio_header *
@@ -213,6 +218,7 @@ taru_make_header(void)
        	hnew->c_tar_linkname = NULL;
        	hnew->c_username = NULL;
        	hnew->c_groupname = NULL;
+	hnew->digsM = NULL;
 	taru_init_header(hnew);
 	return hnew;
 }
@@ -285,8 +291,8 @@ taru_print_tar_ls_list(STROB * buf, struct new_cpio_header * file_hdr, int vflag
 			file_hdr,
 			(time_t)(0),
 			buf,
-			/* uname */ ahsStaticGetTarUsername(file_hdr),
-			/* gname */ahsStaticGetTarGroupname(file_hdr),
+			ahsStaticGetTarUsername(file_hdr),
+			ahsStaticGetTarGroupname(file_hdr),
 			type,
 			vflag);
 	else
