@@ -15,13 +15,10 @@
 #include "swexdistribution.h"
 
 extern "C" {
-#include "swcommon_options.h"
-#include "swevents.h"
-#include "swevents_array.h"
 #include "swcommon.h"
 #include "usgetopt.h"
 }
-
+#include "swmain.h"
 int
 main (int argc, char ** argv)
 {
