@@ -43,7 +43,7 @@ swsum=`printf "\
 		control_directory \"\"\n\
 		directory . /\n\
 		file *\n\n" \
-		| swpackage -s - \
+		| swpackage -s - --no-defaults \
 			--swbis-numeric-owner=false \
 			$SWPACKAGE_FORMAT_OPTIONS \
 			--no-catalog \
